Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaBranch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

A data branch that stores all instances of Products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaBranch

Returns a new instance of GoogleCloudRetailV2alphaBranch.



1763
1764
1765
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. Human readable name of the branch to display in the UI. Corresponds to the JSON property displayName

Returns:

  • (String)


1727
1728
1729
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1727

def display_name
  @display_name
end

#is_defaultBoolean Also known as: is_default?

Output only. Indicates whether this branch is set as the default branch of its parent catalog. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


1733
1734
1735
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1733

def is_default
  @is_default
end

#last_product_import_timeString

Output only. Timestamp of last import through ProductService.ImportProducts. Empty value means no import has been made to this branch. Corresponds to the JSON property lastProductImportTime

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1740

def last_product_import_time
  @last_product_import_time
end

#nameString

Immutable. Full resource name of the branch, such as projects/*/locations/ global/catalogs/default_catalog/branches/branch_id. Corresponds to the JSON property name

Returns:

  • (String)


1746
1747
1748
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1746

def name
  @name
end

#product_count_statsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaBranchProductCountStatistic>

Output only. Statistics for number of products in the branch, provided for different scopes. This field is not populated in BranchView.BRANCH_VIEW_BASIC view. Corresponds to the JSON property productCountStats



1753
1754
1755
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1753

def product_count_stats
  @product_count_stats
end

#quality_metricsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaBranchQualityMetric>

Output only. The quality metrics measured among products of this branch. See QualityMetric.requirement_key for supported metrics. Metrics could be missing if failed to retrieve. This field is not populated in BranchView. BRANCH_VIEW_BASIC view. Corresponds to the JSON property qualityMetrics



1761
1762
1763
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1761

def quality_metrics
  @quality_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1768
1769
1770
1771
1772
1773
1774
1775
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1768

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_default = args[:is_default] if args.key?(:is_default)
  @last_product_import_time = args[:last_product_import_time] if args.key?(:last_product_import_time)
  @name = args[:name] if args.key?(:name)
  @product_count_stats = args[:product_count_stats] if args.key?(:product_count_stats)
  @quality_metrics = args[:quality_metrics] if args.key?(:quality_metrics)
end