Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalogAttributeFacetConfigIgnoredFacetValues
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalogAttributeFacetConfigIgnoredFacetValues
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Facet values to ignore on facets during the specified time range for the given SearchResponse.Facet.key attribute.
Instance Attribute Summary collapse
-
#end_time ⇒ String
If start time is empty and end time is not empty, then ignore these facet values before end time.
-
#start_time ⇒ String
Time range for the current list of facet values to ignore.
-
#values ⇒ Array<String>
List of facet values to ignore for the following time range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalogAttributeFacetConfigIgnoredFacetValues
constructor
A new instance of GoogleCloudRetailV2alphaCatalogAttributeFacetConfigIgnoredFacetValues.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalogAttributeFacetConfigIgnoredFacetValues
Returns a new instance of GoogleCloudRetailV2alphaCatalogAttributeFacetConfigIgnoredFacetValues.
2133 2134 2135 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
If start time is empty and end time is not empty, then ignore these facet
values before end time.
Corresponds to the JSON property endTime
2115 2116 2117 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2115 def end_time @end_time end |
#start_time ⇒ String
Time range for the current list of facet values to ignore. If multiple time
ranges are specified for an facet value for the current attribute, consider
all of them. If both are empty, ignore always. If start time and end time are
set, then start time must be before end time. If start time is not empty and
end time is empty, then will ignore these facet values after the start time.
Corresponds to the JSON property startTime
2124 2125 2126 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2124 def start_time @start_time end |
#values ⇒ Array<String>
List of facet values to ignore for the following time range. The facet values
are the same as the attribute values. There is a limit of 10 values per
instance of IgnoredFacetValues. Each value can have at most 128 characters.
Corresponds to the JSON property values
2131 2132 2133 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2131 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2138 2139 2140 2141 2142 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2138 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) @values = args[:values] if args.key?(:values) end |