Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalogAttributeFacetConfigMergedFacet
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalogAttributeFacetConfigMergedFacet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
The current facet key (i.e. attribute config) maps into the merged_facet_key. A facet key can have at most one child. The current facet key and the merged facet key need both to be textual custom attributes or both numerical custom attributes (same type).
Instance Attribute Summary collapse
-
#merged_facet_key ⇒ String
The merged facet key should be a valid facet key that is different than the facet key of the current catalog attribute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalogAttributeFacetConfigMergedFacet
constructor
A new instance of GoogleCloudRetailV2alphaCatalogAttributeFacetConfigMergedFacet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalogAttributeFacetConfigMergedFacet
Returns a new instance of GoogleCloudRetailV2alphaCatalogAttributeFacetConfigMergedFacet.
2162 2163 2164 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#merged_facet_key ⇒ String
The merged facet key should be a valid facet key that is different than the
facet key of the current catalog attribute. We refer this is merged facet key
as the child of the current catalog attribute. This merged facet key can't be
a parent of another facet key (i.e. no directed path of length 2). This merged
facet key needs to be either a textual custom attribute or a numerical custom
attribute.
Corresponds to the JSON property mergedFacetKey
2160 2161 2162 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2160 def merged_facet_key @merged_facet_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2167 2168 2169 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2167 def update!(**args) @merged_facet_key = args[:merged_facet_key] if args.key?(:merged_facet_key) end |