Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalogAttributeFacetConfigRerankConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalogAttributeFacetConfigRerankConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Options to rerank based on facet values engaged by the user for the current key. That key needs to be a custom textual key and facetable. To use this control, you also need to pass all the facet keys engaged by the user in the request using the field [SearchRequest.FacetSpec]. In particular, if you don't pass the facet keys engaged that you want to rerank on, this control won't be effective. Moreover, to obtain better results, the facet values that you want to rerank on should be close to English (ideally made of words, underscores, and spaces).
Instance Attribute Summary collapse
-
#facet_values ⇒ Array<String>
If empty, rerank on all facet values for the current key.
-
#rerank_facet ⇒ Boolean
(also: #rerank_facet?)
If set to true, then we also rerank the dynamic facets based on the facet values engaged by the user for the current attribute key during serving.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalogAttributeFacetConfigRerankConfig
constructor
A new instance of GoogleCloudRetailV2alphaCatalogAttributeFacetConfigRerankConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalogAttributeFacetConfigRerankConfig
Returns a new instance of GoogleCloudRetailV2alphaCatalogAttributeFacetConfigRerankConfig.
2226 2227 2228 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facet_values ⇒ Array<String>
If empty, rerank on all facet values for the current key. Otherwise, will
rerank on the facet values from this list only.
Corresponds to the JSON property facetValues
2217 2218 2219 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2217 def facet_values @facet_values end |
#rerank_facet ⇒ Boolean Also known as: rerank_facet?
If set to true, then we also rerank the dynamic facets based on the facet
values engaged by the user for the current attribute key during serving.
Corresponds to the JSON property rerankFacet
2223 2224 2225 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2223 def rerank_facet @rerank_facet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2231 2232 2233 2234 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2231 def update!(**args) @facet_values = args[:facet_values] if args.key?(:facet_values) @rerank_facet = args[:rerank_facet] if args.key?(:rerank_facet) end |