Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Resource that represents completion results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult

Returns a new instance of GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult.



2440
2441
2442
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_promptsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResultAgentPrompt>

Conversational prompts to trigger agents like Shopping Agent. There may be multiple prompts for a single suggestion. This is an experimental feature for select customers. If you want to receive this prompt information, reach out to the Retail support team. Corresponds to the JSON property agentPrompts



2410
2411
2412
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2410

def agent_prompts
  @agent_prompts
end

#attributesHash<String,Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCustomAttribute>

Custom attributes for the suggestion term. * For user-data, the attributes are additional custom attributes ingested through BigQuery. * For cloud- retail, the attributes are product attributes generated by Cloud Retail. It requires UserEvent.product_details is imported properly. Corresponds to the JSON property attributes



2418
2419
2420
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2418

def attributes
  @attributes
end

#facetsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseFacet>

Facet information for the suggestion term. Gives the number of items resulting from a search with this suggestion term for each facet. This is an experimental feature for limited customers. If you want to receive this facet information, reach out to the Retail support team. Corresponds to the JSON property facets



2426
2427
2428
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2426

def facets
  @facets
end

#suggestionString

The suggestion for the query. Corresponds to the JSON property suggestion

Returns:

  • (String)


2431
2432
2433
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2431

def suggestion
  @suggestion
end

#total_product_countFixnum

Total number of products associated with a search with this suggestion. This is an experimental feature for limited customers. If you want to receive this product count information, reach out to the Retail support team. Corresponds to the JSON property totalProductCount

Returns:

  • (Fixnum)


2438
2439
2440
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2438

def total_product_count
  @total_product_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2445
2446
2447
2448
2449
2450
2451
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2445

def update!(**args)
  @agent_prompts = args[:agent_prompts] if args.key?(:agent_prompts)
  @attributes = args[:attributes] if args.key?(:attributes)
  @facets = args[:facets] if args.key?(:facets)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
  @total_product_count = args[:total_product_count] if args.key?(:total_product_count)
end