Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Catalog level autocomplete config for customers to customize autocomplete feature's settings.
Instance Attribute Summary collapse
-
#allowlist_input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig
The input config source for completion data.
-
#auto_learning ⇒ Boolean
(also: #auto_learning?)
If set to true, the auto learning function is enabled.
-
#denylist_input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig
The input config source for completion data.
-
#last_allowlist_import_operation ⇒ String
Output only.
-
#last_denylist_import_operation ⇒ String
Output only.
-
#last_suggestions_import_operation ⇒ String
Output only.
-
#matching_order ⇒ String
Specifies the matching order for autocomplete suggestions, e.g., a query consisting of 'sh' with 'out-of-order' specified would suggest "women's shoes", whereas a query of 'red s' with 'exact-prefix' specified would suggest "red shoes".
-
#max_suggestions ⇒ Fixnum
The maximum number of autocomplete suggestions returned per term.
-
#min_prefix_length ⇒ Fixnum
The minimum number of characters needed to be typed in order to get suggestions.
-
#name ⇒ String
Required.
-
#suggestions_input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig
The input config source for completion data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCompletionConfig
constructor
A new instance of GoogleCloudRetailV2alphaCompletionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCompletionConfig
Returns a new instance of GoogleCloudRetailV2alphaCompletionConfig.
2571 2572 2573 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowlist_input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig
The input config source for completion data.
Corresponds to the JSON property allowlistInputConfig
2500 2501 2502 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2500 def allowlist_input_config @allowlist_input_config end |
#auto_learning ⇒ Boolean Also known as: auto_learning?
If set to true, the auto learning function is enabled. Auto learning uses user
data to generate suggestions using ML techniques. Default value is false. Only
after enabling auto learning can users use cloud-retail data in
CompleteQueryRequest.
Corresponds to the JSON property autoLearning
2508 2509 2510 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2508 def auto_learning @auto_learning end |
#denylist_input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig
The input config source for completion data.
Corresponds to the JSON property denylistInputConfig
2514 2515 2516 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2514 def denylist_input_config @denylist_input_config end |
#last_allowlist_import_operation ⇒ String
Output only. Name of the LRO corresponding to the latest allowlist import. Can
use GetOperation API to retrieve the latest state of the Long Running
Operation.
Corresponds to the JSON property lastAllowlistImportOperation
2521 2522 2523 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2521 def last_allowlist_import_operation @last_allowlist_import_operation end |
#last_denylist_import_operation ⇒ String
Output only. Name of the LRO corresponding to the latest denylist import. Can
use GetOperation API to retrieve the latest state of the Long Running
Operation.
Corresponds to the JSON property lastDenylistImportOperation
2528 2529 2530 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2528 def last_denylist_import_operation @last_denylist_import_operation end |
#last_suggestions_import_operation ⇒ String
Output only. Name of the LRO corresponding to the latest suggestion terms list
import. Can use GetOperation API method to retrieve the latest state of the
Long Running Operation.
Corresponds to the JSON property lastSuggestionsImportOperation
2535 2536 2537 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2535 def last_suggestions_import_operation @last_suggestions_import_operation end |
#matching_order ⇒ String
Specifies the matching order for autocomplete suggestions, e.g., a query
consisting of 'sh' with 'out-of-order' specified would suggest "women's shoes",
whereas a query of 'red s' with 'exact-prefix' specified would suggest "red
shoes". Currently supported values: * 'out-of-order' * 'exact-prefix' Default
value: 'exact-prefix'.
Corresponds to the JSON property matchingOrder
2544 2545 2546 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2544 def matching_order @matching_order end |
#max_suggestions ⇒ Fixnum
The maximum number of autocomplete suggestions returned per term. Default
value is 20. If left unset or set to 0, then will fallback to default value.
Value range is 1 to 20.
Corresponds to the JSON property maxSuggestions
2551 2552 2553 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2551 def max_suggestions @max_suggestions end |
#min_prefix_length ⇒ Fixnum
The minimum number of characters needed to be typed in order to get
suggestions. Default value is 2. If left unset or set to 0, then will fallback
to default value. Value range is 1 to 20.
Corresponds to the JSON property minPrefixLength
2558 2559 2560 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2558 def min_prefix_length @min_prefix_length end |
#name ⇒ String
Required. Immutable. Fully qualified name projects/*/locations/*/catalogs/*/
completionConfig
Corresponds to the JSON property name
2564 2565 2566 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2564 def name @name end |
#suggestions_input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig
The input config source for completion data.
Corresponds to the JSON property suggestionsInputConfig
2569 2570 2571 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2569 def suggestions_input_config @suggestions_input_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2576 def update!(**args) @allowlist_input_config = args[:allowlist_input_config] if args.key?(:allowlist_input_config) @auto_learning = args[:auto_learning] if args.key?(:auto_learning) @denylist_input_config = args[:denylist_input_config] if args.key?(:denylist_input_config) @last_allowlist_import_operation = args[:last_allowlist_import_operation] if args.key?(:last_allowlist_import_operation) @last_denylist_import_operation = args[:last_denylist_import_operation] if args.key?(:last_denylist_import_operation) @last_suggestions_import_operation = args[:last_suggestions_import_operation] if args.key?(:last_suggestions_import_operation) @matching_order = args[:matching_order] if args.key?(:matching_order) @max_suggestions = args[:max_suggestions] if args.key?(:max_suggestions) @min_prefix_length = args[:min_prefix_length] if args.key?(:min_prefix_length) @name = args[:name] if args.key?(:name) @suggestions_input_config = args[:suggestions_input_config] if args.key?(:suggestions_input_config) end |