Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaControl
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaControl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Configures dynamic metadata that can be linked to a ServingConfig and affect search or recommendation results at serving time.
Instance Attribute Summary collapse
-
#associated_serving_config_ids ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Immutable.
-
#rule ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaRule
A rule is a condition-action pair * A condition defines when a rule is to be triggered.
-
#search_solution_use_case ⇒ Array<String>
Specifies the use case for the control.
-
#solution_types ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaControl
constructor
A new instance of GoogleCloudRetailV2alphaControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaControl
Returns a new instance of GoogleCloudRetailV2alphaControl.
2786 2787 2788 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_serving_config_ids ⇒ Array<String>
Output only. List of serving config ids that are associated with this control
in the same Catalog. Note the association is managed via the ServingConfig,
this is an output only denormalized view.
Corresponds to the JSON property associatedServingConfigIds
2748 2749 2750 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2748 def associated_serving_config_ids @associated_serving_config_ids end |
#display_name ⇒ String
Required. The human readable control display name. Used in Retail UI. This
field must be a UTF-8 encoded string with a length limit of 128 characters.
Otherwise, an INVALID_ARGUMENT error is thrown.
Corresponds to the JSON property displayName
2755 2756 2757 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2755 def display_name @display_name end |
#name ⇒ String
Immutable. Fully qualified name projects/*/locations/global/catalogs/*/
controls/*
Corresponds to the JSON property name
2761 2762 2763 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2761 def name @name end |
#rule ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaRule
A rule is a condition-action pair * A condition defines when a rule is to be
triggered. * An action specifies what occurs on that trigger. Currently rules
only work for controls with SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property rule
2768 2769 2770 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2768 def rule @rule end |
#search_solution_use_case ⇒ Array<String>
Specifies the use case for the control. Affects what condition fields can be
set. Only settable by search controls. Will default to
SEARCH_SOLUTION_USE_CASE_SEARCH if not specified. Currently only allow one
search_solution_use_case per control.
Corresponds to the JSON property searchSolutionUseCase
2776 2777 2778 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2776 def search_solution_use_case @search_solution_use_case end |
#solution_types ⇒ Array<String>
Required. Immutable. The solution types that the control is used for.
Currently we support setting only one type of solution at creation time. Only
SOLUTION_TYPE_SEARCH value is supported at the moment. If no solution type is
provided at creation time, will default to SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property solutionTypes
2784 2785 2786 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2784 def solution_types @solution_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2791 2792 2793 2794 2795 2796 2797 2798 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2791 def update!(**args) @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @rule = args[:rule] if args.key?(:rule) @search_solution_use_case = args[:search_solution_use_case] if args.key?(:search_solution_use_case) @solution_types = args[:solution_types] if args.key?(:solution_types) end |