Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchCustomizationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

The public proto to represent the conversational search customization config. It will be converted to the internal proto in the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchCustomizationConfig

Returns a new instance of GoogleCloudRetailV2alphaConversationalSearchCustomizationConfig.



2824
2825
2826
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalogString

Required. Resource name of the catalog. Format: projects/project/locations/ location/catalogs/catalog Corresponds to the JSON property catalog

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2810

def catalog
  @catalog
end

#intent_classification_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfig

The public proto to represent the intent classification config. It will be converted to the internal proto in the backend. Corresponds to the JSON property intentClassificationConfig



2816
2817
2818
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2816

def intent_classification_config
  @intent_classification_config
end

#retailer_display_nameString

Optional. The retailer's display name that could be used in our LLM answers. Example - "Google" Corresponds to the JSON property retailerDisplayName

Returns:

  • (String)


2822
2823
2824
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2822

def retailer_display_name
  @retailer_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2829
2830
2831
2832
2833
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2829

def update!(**args)
  @catalog = args[:catalog] if args.key?(:catalog)
  @intent_classification_config = args[:intent_classification_config] if args.key?(:intent_classification_config)
  @retailer_display_name = args[:retailer_display_name] if args.key?(:retailer_display_name)
end