Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchRequestSearchParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Search parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchRequestSearchParams

Returns a new instance of GoogleCloudRetailV2alphaConversationalSearchRequestSearchParams.



3002
3003
3004
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpec

Boost specification to boost certain items. Corresponds to the JSON property boostSpec



2982
2983
2984
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2982

def boost_spec
  @boost_spec
end

#canonical_filterString

Optional. The canonical filter string to restrict search results. The syntax of the canonical filter string is the same as SearchRequest.canonical_filter. Corresponds to the JSON property canonicalFilter

Returns:

  • (String)


2988
2989
2990
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2988

def canonical_filter
  @canonical_filter
end

#filterString

Optional. The filter string to restrict search results. The syntax of the filter string is the same as SearchRequest.filter. Corresponds to the JSON property filter

Returns:

  • (String)


2994
2995
2996
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2994

def filter
  @filter
end

#sort_byString

Optional. The sort string to specify the sorting of search results. The syntax of the sort string is the same as SearchRequest.order_by. Corresponds to the JSON property sortBy

Returns:

  • (String)


3000
3001
3002
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3000

def sort_by
  @sort_by
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3007
3008
3009
3010
3011
3012
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3007

def update!(**args)
  @boost_spec = args[:boost_spec] if args.key?(:boost_spec)
  @canonical_filter = args[:canonical_filter] if args.key?(:canonical_filter)
  @filter = args[:filter] if args.key?(:filter)
  @sort_by = args[:sort_by] if args.key?(:sort_by)
end