Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response message for ConversationalSearchService.ConversationalSearch method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchResponse

Returns a new instance of GoogleCloudRetailV2alphaConversationalSearchResponse.



3084
3085
3086
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idString

Conversation UUID. This field will be stored in client side storage to maintain the conversation session with server and will be used for next search request's ConversationalSearchRequest.conversation_id to restore conversation state in server. Corresponds to the JSON property conversationId

Returns:

  • (String)


3045
3046
3047
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3045

def conversation_id
  @conversation_id
end

#conversational_filtering_resultGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponseConversationalFilteringResult

This field specifies all related information that is needed on client side for UI rendering of conversational filtering search. Corresponds to the JSON property conversationalFilteringResult



3051
3052
3053
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3051

def conversational_filtering_result
  @conversational_filtering_result
end

#conversational_text_responseString

The conversational answer-based text response generated by the Server. Corresponds to the JSON property conversationalTextResponse

Returns:

  • (String)


3056
3057
3058
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3056

def conversational_text_response
  @conversational_text_response
end

#followup_questionGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestion

The conversational followup question generated for Intent refinement. Corresponds to the JSON property followupQuestion



3061
3062
3063
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3061

def followup_question
  @followup_question
end

#refined_searchArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponseRefinedSearch>

The proposed refined search queries. They can be used to fetch the relevant search results. When using CONVERSATIONAL_FILTER_ONLY mode, the refined_query from search response will be populated here. Corresponds to the JSON property refinedSearch



3068
3069
3070
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3068

def refined_search
  @refined_search
end

#stateString

Output only. The state of the response generation. Corresponds to the JSON property state

Returns:

  • (String)


3073
3074
3075
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3073

def state
  @state
end

#user_query_typesArray<String>

The types Retail classifies the search query as. Supported values are: - " ORDER_SUPPORT" - "SIMPLE_PRODUCT_SEARCH" - "INTENT_REFINEMENT" - " PRODUCT_DETAILS" - "PRODUCT_COMPARISON" - "DEALS_AND_COUPONS" - " STORE_RELEVANT" - "BLOCKLISTED" - "BEST_PRODUCT" - "RETAIL_SUPPORT" - " DISABLED" Corresponds to the JSON property userQueryTypes

Returns:

  • (Array<String>)


3082
3083
3084
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3082

def user_query_types
  @user_query_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3089

def update!(**args)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @conversational_filtering_result = args[:conversational_filtering_result] if args.key?(:conversational_filtering_result)
  @conversational_text_response = args[:conversational_text_response] if args.key?(:conversational_text_response)
  @followup_question = args[:followup_question] if args.key?(:followup_question)
  @refined_search = args[:refined_search] if args.key?(:refined_search)
  @state = args[:state] if args.key?(:state)
  @user_query_types = args[:user_query_types] if args.key?(:user_query_types)
end