Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestion
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
The conversational followup question generated for Intent refinement.
Instance Attribute Summary collapse
-
#followup_question ⇒ String
The conversational followup question generated for Intent refinement.
-
#suggested_answers ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestionSuggestedAnswer>
The answer options provided to client for the follow-up question.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestion
constructor
A new instance of GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestion
Returns a new instance of GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestion.
3161 3162 3163 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#followup_question ⇒ String
The conversational followup question generated for Intent refinement.
Corresponds to the JSON property followupQuestion
3154 3155 3156 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3154 def followup_question @followup_question end |
#suggested_answers ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchResponseFollowupQuestionSuggestedAnswer>
The answer options provided to client for the follow-up question.
Corresponds to the JSON property suggestedAnswers
3159 3160 3161 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3159 def suggested_answers @suggested_answers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3166 3167 3168 3169 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3166 def update!(**args) @followup_question = args[:followup_question] if args.key?(:followup_question) @suggested_answers = args[:suggested_answers] if args.key?(:suggested_answers) end |