Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaGenerativeQuestionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Configuration for a single generated question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaGenerativeQuestionConfig

Returns a new instance of GoogleCloudRetailV2alphaGenerativeQuestionConfig.



3818
3819
3820
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_in_conversationBoolean Also known as: allowed_in_conversation?

Optional. Whether the question is asked at serving time. Corresponds to the JSON property allowedInConversation

Returns:

  • (Boolean)


3783
3784
3785
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3783

def allowed_in_conversation
  @allowed_in_conversation
end

#catalogString

Required. Resource name of the catalog. Format: projects/project/locations/ location/catalogs/catalog Corresponds to the JSON property catalog

Returns:

  • (String)


3790
3791
3792
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3790

def catalog
  @catalog
end

#example_valuesArray<String>

Output only. Values that can be used to answer the question. Corresponds to the JSON property exampleValues

Returns:

  • (Array<String>)


3795
3796
3797
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3795

def example_values
  @example_values
end

#facetString

Required. The facet to which the question is associated. Corresponds to the JSON property facet

Returns:

  • (String)


3800
3801
3802
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3800

def facet
  @facet
end

#final_questionString

Optional. The question that will be used at serving time. Question can have a max length of 300 bytes. When not populated, generated_question should be used. Corresponds to the JSON property finalQuestion

Returns:

  • (String)


3806
3807
3808
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3806

def final_question
  @final_question
end

#frequencyFloat

Output only. The ratio of how often a question was asked. Corresponds to the JSON property frequency

Returns:

  • (Float)


3811
3812
3813
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3811

def frequency
  @frequency
end

#generated_questionString

Output only. The LLM generated question. Corresponds to the JSON property generatedQuestion

Returns:

  • (String)


3816
3817
3818
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3816

def generated_question
  @generated_question
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3823
3824
3825
3826
3827
3828
3829
3830
3831
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3823

def update!(**args)
  @allowed_in_conversation = args[:allowed_in_conversation] if args.key?(:allowed_in_conversation)
  @catalog = args[:catalog] if args.key?(:catalog)
  @example_values = args[:example_values] if args.key?(:example_values)
  @facet = args[:facet] if args.key?(:facet)
  @final_question = args[:final_question] if args.key?(:final_question)
  @frequency = args[:frequency] if args.key?(:frequency)
  @generated_question = args[:generated_question] if args.key?(:generated_question)
end