Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaGenerativeQuestionsFeatureConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaGenerativeQuestionsFeatureConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Configuration for overall generative question feature state.
Instance Attribute Summary collapse
-
#catalog ⇒ String
Required.
-
#feature_enabled ⇒ Boolean
(also: #feature_enabled?)
Optional.
-
#minimum_products ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaGenerativeQuestionsFeatureConfig
constructor
A new instance of GoogleCloudRetailV2alphaGenerativeQuestionsFeatureConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaGenerativeQuestionsFeatureConfig
Returns a new instance of GoogleCloudRetailV2alphaGenerativeQuestionsFeatureConfig.
3856 3857 3858 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog ⇒ String
Required. Resource name of the affected catalog. Format: projects/project/
locations/location/catalogs/catalog
Corresponds to the JSON property catalog
3841 3842 3843 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3841 def catalog @catalog end |
#feature_enabled ⇒ Boolean Also known as: feature_enabled?
Optional. Determines whether questions will be used at serving time. Note:
This feature cannot be enabled until initial data requirements are satisfied.
Corresponds to the JSON property featureEnabled
3847 3848 3849 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3847 def feature_enabled @feature_enabled end |
#minimum_products ⇒ Fixnum
Optional. Minimum number of products in the response to trigger follow-up
questions. Value must be 0 or positive.
Corresponds to the JSON property minimumProducts
3854 3855 3856 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3854 def minimum_products @minimum_products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3861 3862 3863 3864 3865 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3861 def update!(**args) @catalog = args[:catalog] if args.key?(:catalog) @feature_enabled = args[:feature_enabled] if args.key?(:feature_enabled) @minimum_products = args[:minimum_products] if args.key?(:minimum_products) end |