Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportCompletionDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the ImportCompletionDataRequest. If the long running operation is done, this message is returned by the google.longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportCompletionDataResponse

Returns a new instance of GoogleCloudRetailV2alphaImportCompletionDataResponse.



4009
4010
4011
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2alpha::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4007
4008
4009
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4007

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4014
4015
4016
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4014

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end