Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Metadata related to the progress of the Import operation. This is returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportMetadata

Returns a new instance of GoogleCloudRetailV2alphaImportMetadata.



4056
4057
4058
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


4020
4021
4022
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4020

def create_time
  @create_time
end

#failure_countFixnum

Count of entries that encountered errors while processing. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


4025
4026
4027
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4025

def failure_count
  @failure_count
end

#notification_pubsub_topicString

Pub/Sub topic for receiving notification. If this field is set, when the import is finished, a notification is sent to specified Pub/Sub topic. The message data is JSON string of a Operation. Format of the Pub/Sub topic is projects/project/topics/topic`. Corresponds to the JSON propertynotificationPubsubTopic`

Returns:

  • (String)


4033
4034
4035
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4033

def notification_pubsub_topic
  @notification_pubsub_topic
end

#request_idString

Deprecated. This field is never set. Corresponds to the JSON property requestId

Returns:

  • (String)


4038
4039
4040
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4038

def request_id
  @request_id
end

#success_countFixnum

Count of entries that were processed successfully. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


4043
4044
4045
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4043

def success_count
  @success_count
end

#transformed_user_events_metadataGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaTransformedUserEventsMetadata

Metadata related to transform user events operation. Corresponds to the JSON property transformedUserEventsMetadata



4048
4049
4050
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4048

def 
  @transformed_user_events_metadata
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


4054
4055
4056
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4054

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4061

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @notification_pubsub_topic = args[:notification_pubsub_topic] if args.key?(:notification_pubsub_topic)
  @request_id = args[:request_id] if args.key?(:request_id)
  @success_count = args[:success_count] if args.key?(:success_count)
  @transformed_user_events_metadata = args[:transformed_user_events_metadata] if args.key?(:transformed_user_events_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end