Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportProductsRequest
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportProductsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Request message for Import methods.
Instance Attribute Summary collapse
-
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportErrorsConfig
Configuration of destination for Import related errors.
-
#input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductInputConfig
The input config source for products.
-
#notification_pubsub_topic ⇒ String
Full Pub/Sub topic name for receiving notification.
-
#reconciliation_mode ⇒ String
The mode of reconciliation between existing products and the products to be imported.
-
#request_id ⇒ String
Deprecated.
-
#skip_default_branch_protection ⇒ Boolean
(also: #skip_default_branch_protection?)
If true, this performs the FULL import even if it would delete a large proportion of the products in the default branch, which could potentially cause outages if you have live predict/search traffic.
-
#update_mask ⇒ String
Indicates which fields in the provided imported
productsto update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportProductsRequest
constructor
A new instance of GoogleCloudRetailV2alphaImportProductsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportProductsRequest
Returns a new instance of GoogleCloudRetailV2alphaImportProductsRequest.
4154 4155 4156 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportErrorsConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorsConfig
4107 4108 4109 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4107 def errors_config @errors_config end |
#input_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductInputConfig
The input config source for products.
Corresponds to the JSON property inputConfig
4112 4113 4114 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4112 def input_config @input_config end |
#notification_pubsub_topic ⇒ String
Full Pub/Sub topic name for receiving notification. If this field is set, when
the import is finished, a notification is sent to specified Pub/Sub topic. The
message data is JSON string of a Operation. Format of the Pub/Sub topic is
projects/project/topics/topic`. It has to be within the same project as
ImportProductsRequest.parent. Make sure that bothcloud-retail-customer-data-
access@system.gserviceaccount.comandservice-@gcp-sa-retail.iam.
gserviceaccount.comhave thepubsub.topics.publishIAM permission on the
topic. Only supported when ImportProductsRequest.reconciliation_mode is set to
FULL.
Corresponds to the JSON propertynotificationPubsubTopic`
4125 4126 4127 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4125 def notification_pubsub_topic @notification_pubsub_topic end |
#reconciliation_mode ⇒ String
The mode of reconciliation between existing products and the products to be
imported. Defaults to ReconciliationMode.INCREMENTAL.
Corresponds to the JSON property reconciliationMode
4131 4132 4133 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4131 def reconciliation_mode @reconciliation_mode end |
#request_id ⇒ String
Deprecated. This field has no effect.
Corresponds to the JSON property requestId
4136 4137 4138 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4136 def request_id @request_id end |
#skip_default_branch_protection ⇒ Boolean Also known as: skip_default_branch_protection?
If true, this performs the FULL import even if it would delete a large
proportion of the products in the default branch, which could potentially
cause outages if you have live predict/search traffic. Only supported when
ImportProductsRequest.reconciliation_mode is set to FULL.
Corresponds to the JSON property skipDefaultBranchProtection
4144 4145 4146 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4144 def skip_default_branch_protection @skip_default_branch_protection end |
#update_mask ⇒ String
Indicates which fields in the provided imported products to update. If not
set, all fields are updated. If provided, only the existing product fields are
updated. Missing products will not be created.
Corresponds to the JSON property updateMask
4152 4153 4154 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4152 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4159 def update!(**args) @errors_config = args[:errors_config] if args.key?(:errors_config) @input_config = args[:input_config] if args.key?(:input_config) @notification_pubsub_topic = args[:notification_pubsub_topic] if args.key?(:notification_pubsub_topic) @reconciliation_mode = args[:reconciliation_mode] if args.key?(:reconciliation_mode) @request_id = args[:request_id] if args.key?(:request_id) @skip_default_branch_protection = args[:skip_default_branch_protection] if args.key?(:skip_default_branch_protection) @update_mask = args[:update_mask] if args.key?(:update_mask) end |