Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportUserEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportUserEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportErrorsConfig
Configuration of destination for Import related errors.
-
#import_summary ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaUserEventImportSummary
A summary of import result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportUserEventsResponse
constructor
A new instance of GoogleCloudRetailV2alphaImportUserEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportUserEventsResponse
Returns a new instance of GoogleCloudRetailV2alphaImportUserEventsResponse.
4244 4245 4246 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
4231 4232 4233 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4231 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportErrorsConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorsConfig
4236 4237 4238 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4236 def errors_config @errors_config end |
#import_summary ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaUserEventImportSummary
A summary of import result. The UserEventImportSummary summarizes the import
status for user events.
Corresponds to the JSON property importSummary
4242 4243 4244 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4242 def import_summary @import_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4249 4250 4251 4252 4253 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4249 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @import_summary = args[:import_summary] if args.key?(:import_summary) end |