Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaListModelsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaListModelsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response to a ListModelRequest.
Instance Attribute Summary collapse
-
#models ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModel>
List of Models.
-
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaListModelsResponse
constructor
A new instance of GoogleCloudRetailV2alphaListModelsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaListModelsResponse
Returns a new instance of GoogleCloudRetailV2alphaListModelsResponse.
4549 4550 4551 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#models ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModel>
List of Models.
Corresponds to the JSON property models
4542 4543 4544 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4542 def models @models end |
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Corresponds to the JSON property nextPageToken
4547 4548 4549 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4547 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4554 4555 4556 4557 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4554 def update!(**args) @models = args[:models] if args.key?(:models) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |