Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaMerchantCenterAccountLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Represents a link between a Merchant Center account and a branch. After a link is established, products from the linked Merchant Center account are streamed to the linked branch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaMerchantCenterAccountLink

Returns a new instance of GoogleCloudRetailV2alphaMerchantCenterAccountLink.



4888
4889
4890
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branch_idString

Required. The branch ID (e.g. 0/1/2) within the catalog that products from merchant_center_account_id are streamed to. When updating this field, an empty value will use the currently configured default branch. However, changing the default branch later on won't change the linked branch here. A single branch ID can only have one linked Merchant Center account ID. Corresponds to the JSON property branchId

Returns:

  • (String)


4825
4826
4827
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4825

def branch_id
  @branch_id
end

#feed_filtersArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaMerchantCenterAccountLinkMerchantCenterFeedFilter>

Criteria for the Merchant Center feeds to be ingested via the link. All offers will be ingested if the list is empty. Otherwise the offers will be ingested from selected feeds. Corresponds to the JSON property feedFilters



4832
4833
4834
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4832

def feed_filters
  @feed_filters
end

#feed_labelString

The FeedLabel used to perform filtering. Note: this replaces region_id. Example value: US. Example value: FeedLabel1. Corresponds to the JSON property feedLabel

Returns:

  • (String)


4839
4840
4841
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4839

def feed_label
  @feed_label
end

#idString

Output only. Immutable. MerchantCenterAccountLink identifier, which is the final component of name. This field is auto generated and follows the convention: BranchId_MerchantCenterAccountId. projects/*/locations/global/ catalogs/default_catalog/merchantCenterAccountLinks/id_1. Corresponds to the JSON property id

Returns:

  • (String)


4847
4848
4849
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4847

def id
  @id
end

#language_codeString

Language of the title/description and other string attributes. Use language tags defined by BCP 47. ISO 639-1. This specifies the language of offers in Merchant Center that will be accepted. If empty, no language filtering will be performed. Example value: en. Corresponds to the JSON property languageCode

Returns:

  • (String)


4856
4857
4858
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4856

def language_code
  @language_code
end

#merchant_center_account_idFixnum

Required. The linked Merchant center account id. The account must be a standalone account or a sub-account of a MCA. Corresponds to the JSON property merchantCenterAccountId

Returns:

  • (Fixnum)


4863
4864
4865
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4863

def 
  @merchant_center_account_id
end

#nameString

Output only. Immutable. Full resource name of the Merchant Center Account Link, such as projects/*/locations/global/catalogs/default_catalog/ merchantCenterAccountLinks/merchant_center_account_link. Corresponds to the JSON property name

Returns:

  • (String)


4870
4871
4872
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4870

def name
  @name
end

#project_idString

Output only. Google Cloud project ID. Corresponds to the JSON property projectId

Returns:

  • (String)


4875
4876
4877
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4875

def project_id
  @project_id
end

#sourceString

Optional. An optional arbitrary string that could be used as a tag for tracking link source. Corresponds to the JSON property source

Returns:

  • (String)


4881
4882
4883
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4881

def source
  @source
end

#stateString

Output only. Represents the state of the link. Corresponds to the JSON property state

Returns:

  • (String)


4886
4887
4888
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4886

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4893

def update!(**args)
  @branch_id = args[:branch_id] if args.key?(:branch_id)
  @feed_filters = args[:feed_filters] if args.key?(:feed_filters)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @id = args[:id] if args.key?(:id)
  @language_code = args[:language_code] if args.key?(:language_code)
  @merchant_center_account_id = args[:merchant_center_account_id] if args.key?(:merchant_center_account_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @source = args[:source] if args.key?(:source)
  @state = args[:state] if args.key?(:state)
end