Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaMerchantCenterLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Represents a link between a Merchant Center account and a branch. After a link is established, products from the linked Merchant Center account are streamed to the linked branch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaMerchantCenterLink

Returns a new instance of GoogleCloudRetailV2alphaMerchantCenterLink.



4997
4998
4999
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branch_idString

The branch ID (e.g. 0/1/2) within this catalog that products from merchant_center_account_id are streamed to. When updating this field, an empty value will use the currently configured default branch. However, changing the default branch later on won't change the linked branch here. A single branch ID can only have one linked Merchant Center account ID. Corresponds to the JSON property branchId

Returns:

  • (String)


4955
4956
4957
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4955

def branch_id
  @branch_id
end

#destinationsArray<String>

String representing the destination to import for, all if left empty. List of possible values is given in Included destination. List of allowed string values: "Shopping_ads", " Buy_on_google_listings", "Display_ads", "Local_inventory _ads", "Free_listings" , "Free_local_listings" NOTE: The string values are case sensitive. Corresponds to the JSON property destinations

Returns:

  • (Array<String>)


4964
4965
4966
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4964

def destinations
  @destinations
end

#feedsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaMerchantCenterFeedFilter>

Criteria for the Merchant Center feeds to be ingested via the link. All offers will be ingested if the list is empty. Otherwise the offers will be ingested from selected feeds. Corresponds to the JSON property feeds



4971
4972
4973
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4971

def feeds
  @feeds
end

#language_codeString

Language of the title/description and other string attributes. Use language tags defined by BCP 47. ISO 639-1. This specifies the language of offers in Merchant Center that will be accepted. If empty no language filtering will be performed. Example value: en . Corresponds to the JSON property languageCode

Returns:

  • (String)


4980
4981
4982
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4980

def language_code
  @language_code
end

#merchant_center_account_idFixnum

Required. The linked Merchant Center account ID. The account must be a standalone account or a sub-account of a MCA. Corresponds to the JSON property merchantCenterAccountId

Returns:

  • (Fixnum)


4987
4988
4989
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4987

def 
  @merchant_center_account_id
end

#region_codeString

Region code of offers to accept. 2-letter Uppercase ISO 3166-1 alpha-2 code. List of values can be found here under the region tag. If left blank no region filtering will be performed. Example value: US. Corresponds to the JSON property regionCode

Returns:

  • (String)


4995
4996
4997
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4995

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5002
5003
5004
5005
5006
5007
5008
5009
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5002

def update!(**args)
  @branch_id = args[:branch_id] if args.key?(:branch_id)
  @destinations = args[:destinations] if args.key?(:destinations)
  @feeds = args[:feeds] if args.key?(:feeds)
  @language_code = args[:language_code] if args.key?(:language_code)
  @merchant_center_account_id = args[:merchant_center_account_id] if args.key?(:merchant_center_account_id)
  @region_code = args[:region_code] if args.key?(:region_code)
end