Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
The PageOptimizationConfig for model training. This determines how many panels to optimize for, and which serving configs to consider for each panel. The purpose of this model is to optimize which ServingConfig to show on which panels in way that optimizes the visitors shopping journey.
Instance Attribute Summary collapse
-
#page_optimization_event_type ⇒ String
Required.
-
#panels ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfigPanel>
Required.
-
#restriction ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaModelPageOptimizationConfig
constructor
A new instance of GoogleCloudRetailV2alphaModelPageOptimizationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaModelPageOptimizationConfig
Returns a new instance of GoogleCloudRetailV2alphaModelPageOptimizationConfig.
5286 5287 5288 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_optimization_event_type ⇒ String
Required. The type of UserEvent this page optimization is shown for. Each page
has an associated event type - this will be the corresponding event type for
the page that the page optimization model is used on. Supported types: * add-
to-cart: Products being added to cart. * detail-page-view: Products detail
page viewed. * home-page-view: Homepage viewed * category-page-view:
Homepage viewed * shopping-cart-page-view: User viewing a shopping cart.
home-page-view only allows models with type recommended-for-you. All other
page_optimization_event_type allow all Model.types.
Corresponds to the JSON property pageOptimizationEventType
5272 5273 5274 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5272 def page_optimization_event_type @page_optimization_event_type end |
#panels ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfigPanel>
Required. A list of panel configurations. Limit = 5.
Corresponds to the JSON property panels
5277 5278 5279 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5277 def panels @panels end |
#restriction ⇒ String
Optional. How to restrict results across panels e.g. can the same
ServingConfig be shown on multiple panels at once. If unspecified, default to
UNIQUE_MODEL_RESTRICTION.
Corresponds to the JSON property restriction
5284 5285 5286 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5284 def restriction @restriction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5291 5292 5293 5294 5295 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5291 def update!(**args) @page_optimization_event_type = args[:page_optimization_event_type] if args.key?(:page_optimization_event_type) @panels = args[:panels] if args.key?(:panels) @restriction = args[:restriction] if args.key?(:restriction) end |