Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response message for predict method.
Instance Attribute Summary collapse
-
#attribution_token ⇒ String
A unique attribution token.
-
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
-
#results ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponsePredictionResult>
A list of recommended products.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
True if the validateOnly property was set in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPredictResponse
constructor
A new instance of GoogleCloudRetailV2alphaPredictResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPredictResponse
Returns a new instance of GoogleCloudRetailV2alphaPredictResponse.
5731 5732 5733 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_token ⇒ String
A unique attribution token. This should be included in the UserEvent logs
resulting from this recommendation, which enables accurate attribution of
recommendation model performance.
Corresponds to the JSON property attributionToken
5712 5713 5714 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5712 def attribution_token @attribution_token end |
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
Corresponds to the JSON property missingIds
5717 5718 5719 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5717 def missing_ids @missing_ids end |
#results ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponsePredictionResult>
A list of recommended products. The order represents the ranking (from the
most relevant product to the least).
Corresponds to the JSON property results
5723 5724 5725 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5723 def results @results end |
#validate_only ⇒ Boolean Also known as: validate_only?
True if the validateOnly property was set in the request.
Corresponds to the JSON property validateOnly
5728 5729 5730 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5728 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5736 5737 5738 5739 5740 5741 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5736 def update!(**args) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @missing_ids = args[:missing_ids] if args.key?(:missing_ids) @results = args[:results] if args.key?(:results) @validate_only = args[:validate_only] if args.key?(:validate_only) end |