Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurgeProductsRequest
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurgeProductsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Request message for PurgeProducts method.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#force ⇒ Boolean
(also: #force?)
Actually perform the purge.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurgeProductsRequest
constructor
A new instance of GoogleCloudRetailV2alphaPurgeProductsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurgeProductsRequest
Returns a new instance of GoogleCloudRetailV2alphaPurgeProductsRequest.
6623 6624 6625 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. The filter string to specify the products to be deleted with a
length limit of 5,000 characters. Empty string filter is not allowed. "*"
implies delete all items in a branch. The eligible fields for filtering are: *
availability: Double quoted Product.availability string. * create_time :
in ISO 8601 "zulu" format. Supported syntax: * Comparators (">", "<", ">=", "<=
", "="). Examples: * create_time <= "2015-02-13T17:05:46Z" * availability = "
IN_STOCK" * Conjunctions ("AND") Examples: * create_time <= "2015-02-13T17:05:
46Z" AND availability = "PREORDER" * Disjunctions ("OR") Examples: *
create_time <= "2015-02-13T17:05:46Z" OR availability = "IN_STOCK" * Can
support nested queries. Examples: * (create_time <= "2015-02-13T17:05:46Z" AND
availability = "PREORDER") OR (create_time >= "2015-02-14T13:03:32Z" AND
availability = "IN_STOCK") * Filter Limits: * Filter should not contain more
than 6 conditions. * Max nesting depth should not exceed 2 levels. Examples
queries: * Delete back order products created before a timestamp. create_time <
= "2015-02-13T17:05:46Z" OR availability = "BACKORDER"
Corresponds to the JSON property filter
6614 6615 6616 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6614 def filter @filter end |
#force ⇒ Boolean Also known as: force?
Actually perform the purge. If force is set to false, the method will return
the expected purge count without deleting any products.
Corresponds to the JSON property force
6620 6621 6622 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6620 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6628 6629 6630 6631 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6628 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) end |