Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurgeProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the PurgeProductsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurgeProductsResponse

Returns a new instance of GoogleCloudRetailV2alphaPurgeProductsResponse.



6623
6624
6625
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The total count of products purged as a result of the operation. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


6614
6615
6616
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6614

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of the product names that will be deleted. Only populated if force is set to false. A max of 100 names will be returned and the names are chosen at random. Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


6621
6622
6623
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6621

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6628
6629
6630
6631
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6628

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end