Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurgeUserEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurgeUserEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Request message for PurgeUserEvents method.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#force ⇒ Boolean
(also: #force?)
Actually perform the purge.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurgeUserEventsRequest
constructor
A new instance of GoogleCloudRetailV2alphaPurgeUserEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurgeUserEventsRequest
Returns a new instance of GoogleCloudRetailV2alphaPurgeUserEventsRequest.
6660 6661 6662 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. The filter string to specify the events to be deleted with a length
limit of 5,000 characters. Empty string filter is not allowed. The eligible
fields for filtering are: * eventType: Double quoted UserEvent.event_type
string. * eventTime: in ISO 8601 "zulu" format. * visitorId: Double quoted
string. Specifying this will delete all events associated with a visitor. *
userId: Double quoted string. Specifying this will delete all events
associated with a user. Examples: * Deleting all events in a time range:
eventTime > "2012-04-23T18:25:43.511Z" eventTime < "2012-04-23T18:30:43.511Z"
- Deleting specific eventType in time range:
eventTime > "2012-04-23T18:25:43. 511Z" eventType = "detail-page-view"* Deleting all events for a specific visitor:visitorId = "visitor1024"The filtering fields are assumed to have an implicit AND. Corresponds to the JSON propertyfilter
6651 6652 6653 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6651 def filter @filter end |
#force ⇒ Boolean Also known as: force?
Actually perform the purge. If force is set to false, the method will return
the expected purge count without deleting any user events.
Corresponds to the JSON property force
6657 6658 6659 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6657 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6665 6666 6667 6668 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6665 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) end |