Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaRuleFilterAction
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaRuleFilterAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
- Rule Condition: - No Condition.query_terms provided is a global match. - 1 or more Condition.query_terms provided are combined with OR operator. * Action Input: The request query and filter that are applied to the retrieved products, in addition to any filters already provided with the SearchRequest. The AND operator is used to combine the query's existing filters with the filter rule( s). NOTE: May result in 0 results when filters conflict. * Action Result: Filters the returned objects to be ONLY those that passed the filter.
Instance Attribute Summary collapse
-
#filter ⇒ String
A filter to apply on the matching condition results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaRuleFilterAction
constructor
A new instance of GoogleCloudRetailV2alphaRuleFilterAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaRuleFilterAction
Returns a new instance of GoogleCloudRetailV2alphaRuleFilterAction.
7246 7247 7248 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7246 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
A filter to apply on the matching condition results. Supported features: *
filter must be set. * Filter syntax is identical to SearchRequest.filter. For
more information, see Filter. * To
filter products with product ID "product_1" or "product_2", and color "Red" or
"Blue": *(id: ANY("product_1", "product_2")) * *AND * *(colorFamilies: ANY("
Red", "Blue")) *
Corresponds to the JSON property filter
7244 7245 7246 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7244 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7251 7252 7253 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7251 def update!(**args) @filter = args[:filter] if args.key?(:filter) end |