Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpecUserAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

This field specifies the current user answer during the conversational search. This can be either user selected from suggested answers or user input plain text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpecUserAnswer

Returns a new instance of GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpecUserAnswer.



8006
8007
8008
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#selected_answerGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpecUserAnswerSelectedAnswer

This field specifies the selected answers during the conversational search. Corresponds to the JSON property selectedAnswer



7998
7999
8000
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7998

def selected_answer
  @selected_answer
end

#text_answerString

This field specifies the incremental input text from the user during the conversational search. Corresponds to the JSON property textAnswer

Returns:

  • (String)


8004
8005
8006
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8004

def text_answer
  @text_answer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8011
8012
8013
8014
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8011

def update!(**args)
  @selected_answer = args[:selected_answer] if args.key?(:selected_answer)
  @text_answer = args[:text_answer] if args.key?(:text_answer)
end