Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response message for SearchService.Search method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchResponse

Returns a new instance of GoogleCloudRetailV2alphaSearchResponse.



8445
8446
8447
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_controlsArray<String>

The fully qualified resource name of applied controls. Corresponds to the JSON property appliedControls

Returns:

  • (Array<String>)


8362
8363
8364
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8362

def applied_controls
  @applied_controls
end

#attribution_tokenString

A unique search token. This should be included in the UserEvent logs resulting from this search, which enables accurate attribution of search model performance. Corresponds to the JSON property attributionToken

Returns:

  • (String)


8369
8370
8371
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8369

def attribution_token
  @attribution_token
end

#conversational_search_resultGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResult

This field specifies all related information that is needed on client side for UI rendering of conversational retail search. Corresponds to the JSON property conversationalSearchResult



8375
8376
8377
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8375

def conversational_search_result
  @conversational_search_result
end

#corrected_queryString

Contains the spell corrected query, if found. The search results are based on corrected_query by default. However, if SearchRequest.SpellCorrectionSpec.mode is set to SearchRequest.SpellCorrectionSpec.Mode.SUGGESTION_ONLY, the original query is used for search. Corresponds to the JSON property correctedQuery

Returns:

  • (String)


8383
8384
8385
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8383

def corrected_query
  @corrected_query
end

#experiment_infoArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExperimentInfo>

Metadata related to A/B testing experiment associated with this response. Only exists when an experiment is triggered. Corresponds to the JSON property experimentInfo



8389
8390
8391
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8389

def experiment_info
  @experiment_info
end

#facetsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseFacet>

Results of facets requested by user. Corresponds to the JSON property facets



8394
8395
8396
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8394

def facets
  @facets
end

#invalid_condition_boost_specsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec>

The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied during serving. Corresponds to the JSON property invalidConditionBoostSpecs



8400
8401
8402
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8400

def invalid_condition_boost_specs
  @invalid_condition_boost_specs
end

#next_page_tokenString

A token that can be sent as SearchRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8406
8407
8408
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8406

def next_page_token
  @next_page_token
end

#pin_control_metadataGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPinControlMetadata

Metadata for pinning to be returned in the response. This is used for distinguishing between applied vs dropped pins. Corresponds to the JSON property pinControlMetadata



8412
8413
8414
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8412

def 
  @pin_control_metadata
end

#query_expansion_infoGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseQueryExpansionInfo

Information describing query expansion including whether expansion has occurred. Corresponds to the JSON property queryExpansionInfo



8418
8419
8420
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8418

def query_expansion_info
  @query_expansion_info
end

#redirect_uriString

The URI of a customer-defined redirect page. If redirect action is triggered, no search is performed, and only redirect_uri and attribution_token are set in the response. Corresponds to the JSON property redirectUri

Returns:

  • (String)


8425
8426
8427
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8425

def redirect_uri
  @redirect_uri
end

#resultsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseSearchResult>

A list of matched items. The order represents the ranking. Corresponds to the JSON property results



8430
8431
8432
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8430

def results
  @results
end

#tile_navigation_resultGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseTileNavigationResult

This field specifies all related information for tile navigation that will be used in client side. Corresponds to the JSON property tileNavigationResult



8436
8437
8438
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8436

def tile_navigation_result
  @tile_navigation_result
end

#total_sizeFixnum

The estimated total count of matched items irrespective of pagination. The count of results returned by pagination may be less than the total_size that matches. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


8443
8444
8445
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8443

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8450
8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8450

def update!(**args)
  @applied_controls = args[:applied_controls] if args.key?(:applied_controls)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @conversational_search_result = args[:conversational_search_result] if args.key?(:conversational_search_result)
  @corrected_query = args[:corrected_query] if args.key?(:corrected_query)
  @experiment_info = args[:experiment_info] if args.key?(:experiment_info)
  @facets = args[:facets] if args.key?(:facets)
  @invalid_condition_boost_specs = args[:invalid_condition_boost_specs] if args.key?(:invalid_condition_boost_specs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @pin_control_metadata = args[:pin_control_metadata] if args.key?(:pin_control_metadata)
  @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @results = args[:results] if args.key?(:results)
  @tile_navigation_result = args[:tile_navigation_result] if args.key?(:tile_navigation_result)
  @total_size = args[:total_size] if args.key?(:total_size)
end