Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

This field specifies all related information that is needed on client side for UI rendering of conversational retail search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchResponseConversationalSearchResult

Returns a new instance of GoogleCloudRetailV2alphaSearchResponseConversationalSearchResult.



8513
8514
8515
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_filterGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResultAdditionalFilter

Additional filter that client side need to apply. Corresponds to the JSON property additionalFilter



8476
8477
8478
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8476

def additional_filter
  @additional_filter
end

#additional_filtersArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResultAdditionalFilter>

This field is deprecated but will be kept for backward compatibility. There is expected to have only one additional filter and the value will be the same to the same as field additional_filter. Corresponds to the JSON property additionalFilters



8483
8484
8485
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8483

def additional_filters
  @additional_filters
end

#conversation_idString

Conversation UUID. This field will be stored in client side storage to maintain the conversation session with server and will be used for next search request's SearchRequest.ConversationalSearchSpec.conversation_id to restore conversation state in server. Corresponds to the JSON property conversationId

Returns:

  • (String)


8491
8492
8493
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8491

def conversation_id
  @conversation_id
end

#followup_questionString

The follow-up question. e.g., What is the color? Corresponds to the JSON property followupQuestion

Returns:

  • (String)


8496
8497
8498
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8496

def followup_question
  @followup_question
end

#refined_queryString

The current refined query for the conversational search. This field will be used in customer UI that the query in the search bar should be replaced with the refined query. For example, if SearchRequest.query is dress and next SearchRequest.ConversationalSearchSpec.UserAnswer.text_answer is red color, which does not match any product attribute value filters, the refined query will be dress, red color. Corresponds to the JSON property refinedQuery

Returns:

  • (String)


8506
8507
8508
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8506

def refined_query
  @refined_query
end

#suggested_answersArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResultSuggestedAnswer>

The answer options provided to client for the follow-up question. Corresponds to the JSON property suggestedAnswers



8511
8512
8513
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8511

def suggested_answers
  @suggested_answers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8518
8519
8520
8521
8522
8523
8524
8525
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8518

def update!(**args)
  @additional_filter = args[:additional_filter] if args.key?(:additional_filter)
  @additional_filters = args[:additional_filters] if args.key?(:additional_filters)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @followup_question = args[:followup_question] if args.key?(:followup_question)
  @refined_query = args[:refined_query] if args.key?(:refined_query)
  @suggested_answers = args[:suggested_answers] if args.key?(:suggested_answers)
end