Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaUserEvent
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaUserEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
UserEvent captures all metadata information Retail API needs to know about how end users interact with customers' website.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCustomAttribute>
Extra user event features to include in the recommendation model.
-
#attribution_token ⇒ String
Highly recommended for user events that are the result of PredictionService.
-
#cart_id ⇒ String
The ID or name of the associated shopping cart.
-
#completion_detail ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDetail
Detailed completion information including completion attribution token and clicked completion info.
-
#entity ⇒ String
The entity for customers that may run multiple different entities, domains, sites or regions, for example,
Google US,Google Ads,Waymo,google.com,youtube.com, etc. -
#event_time ⇒ String
Only required for UserEventService.ImportUserEvents method.
-
#event_type ⇒ String
Required.
-
#experiment_ids ⇒ Array<String>
A list of identifiers for the independent experiment groups this user event belongs to.
-
#filter ⇒ String
The filter syntax consists of an expression language for constructing a predicate from one or more fields of the products being filtered.
-
#offset ⇒ Fixnum
An integer that specifies the current offset for pagination (the 0-indexed starting location, amongst the products deemed by the API as relevant).
-
#order_by ⇒ String
The order in which products are returned.
-
#page_categories ⇒ Array<String>
Optional.
-
#page_view_id ⇒ String
A unique ID of a web page view.
-
#panels ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPanelInfo>
Optional.
-
#product_details ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductDetail>
The main product details related to the event.
-
#purchase_transaction ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurchaseTransaction
A transaction represents the entire purchase transaction.
-
#referrer_uri ⇒ String
The referrer URL of the current page.
-
#search_query ⇒ String
The user's search query.
-
#session_id ⇒ String
A unique identifier for tracking a visitor session with a length limit of 128 bytes.
-
#uri ⇒ String
Complete URL (window.location.href) of the user's current page.
-
#user_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaUserInfo
Information of an end user.
-
#visitor_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaUserEvent
constructor
A new instance of GoogleCloudRetailV2alphaUserEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaUserEvent
Returns a new instance of GoogleCloudRetailV2alphaUserEvent.
9400 9401 9402 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCustomAttribute>
Extra user event features to include in the recommendation model. If you
provide custom attributes for ingested user events, also include them in the
user events that you associate with prediction requests. Custom attribute
formatting must be consistent between imported events and events provided with
prediction requests. This lets the Retail API use those custom attributes when
training models and serving predictions, which helps improve recommendation
quality. This field needs to pass all below criteria, otherwise an
INVALID_ARGUMENT error is returned: * The key must be a UTF-8 encoded string
with a length limit of 5,000 characters. * For text attributes, at most 400
values are allowed. Empty values are not allowed. Each value must be a UTF-8
encoded string with a length limit of 256 characters. * For number attributes,
at most 400 values are allowed. For product recommendations, an example of
extra user information is traffic_channel, which is how a user arrives at the
site. Users can arrive at the site by coming to the site directly, coming
through Google search, or in other ways.
Corresponds to the JSON property attributes
9211 9212 9213 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9211 def attributes @attributes end |
#attribution_token ⇒ String
Highly recommended for user events that are the result of PredictionService.
Predict. This field enables accurate attribution of recommendation model
performance. The value must be a valid PredictResponse.attribution_token for
user events that are the result of PredictionService.Predict. The value must
be a valid SearchResponse.attribution_token for user events that are the
result of SearchService.Search. This token enables us to accurately attribute
page view or purchase back to the event and the particular predict response
containing this clicked/purchased product. If user clicks on product K in the
recommendation results, pass PredictResponse.attribution_token as a URL
parameter to product K's page. When recording events on product K's page, log
the PredictResponse.attribution_token to this field.
Corresponds to the JSON property attributionToken
9226 9227 9228 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9226 def attribution_token @attribution_token end |
#cart_id ⇒ String
The ID or name of the associated shopping cart. This ID is used to associate
multiple items added or present in the cart before purchase. This can only be
set for add-to-cart, purchase-complete, or shopping-cart-page-view
events.
Corresponds to the JSON property cartId
9234 9235 9236 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9234 def cart_id @cart_id end |
#completion_detail ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDetail
Detailed completion information including completion attribution token and
clicked completion info.
Corresponds to the JSON property completionDetail
9240 9241 9242 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9240 def completion_detail @completion_detail end |
#entity ⇒ String
The entity for customers that may run multiple different entities, domains,
sites or regions, for example, Google US, Google Ads, Waymo, google.com
, youtube.com, etc. We recommend that you set this field to get better per-
entity search, completion, and prediction results.
Corresponds to the JSON property entity
9248 9249 9250 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9248 def entity @entity end |
#event_time ⇒ String
Only required for UserEventService.ImportUserEvents method. Timestamp of when
the user event happened.
Corresponds to the JSON property eventTime
9254 9255 9256 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9254 def event_time @event_time end |
#event_type ⇒ String
Required. User event type. Allowed values are: * add-to-cart: Products being
added to cart. * remove-from-cart: Products being removed from cart. *
category-page-view: Special pages such as sale or promotion pages viewed. *
detail-page-view: Products detail page viewed. * home-page-view: Homepage
viewed. * purchase-complete: User finishing a purchase. * search: Product
search. * shopping-cart-page-view: User viewing a shopping cart.
Corresponds to the JSON property eventType
9264 9265 9266 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9264 def event_type @event_type end |
#experiment_ids ⇒ Array<String>
A list of identifiers for the independent experiment groups this user event
belongs to. This is used to distinguish between user events associated with
different experiment setups (e.g. using Retail API, using different
recommendation models).
Corresponds to the JSON property experimentIds
9272 9273 9274 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9272 def experiment_ids @experiment_ids end |
#filter ⇒ String
The filter syntax consists of an expression language for constructing a
predicate from one or more fields of the products being filtered. See
SearchRequest.filter for definition and syntax. The value must be a UTF-8
encoded string with a length limit of 1,000 characters. Otherwise, an
INVALID_ARGUMENT error is returned.
Corresponds to the JSON property filter
9281 9282 9283 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9281 def filter @filter end |
#offset ⇒ Fixnum
An integer that specifies the current offset for pagination (the 0-indexed
starting location, amongst the products deemed by the API as relevant). See
SearchRequest.offset for definition. If this field is negative, an
INVALID_ARGUMENT is returned. This can only be set for search events. Other
event types should not set this field. Otherwise, an INVALID_ARGUMENT error is
returned.
Corresponds to the JSON property offset
9291 9292 9293 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9291 def offset @offset end |
#order_by ⇒ String
The order in which products are returned. See SearchRequest.order_by for
definition and syntax. The value must be a UTF-8 encoded string with a length
limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned.
This can only be set for search events. Other event types should not set
this field. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property orderBy
9300 9301 9302 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9300 def order_by @order_by end |
#page_categories ⇒ Array<String>
Optional. The categories associated with a category page. To represent the
full path of category, use the '>' sign, with one space on each side, to
separate different hierarchies. If '>' is part of the category name, replace
it with other character(s). Category pages include special pages such as sales
or promotions. For instance, a special sale page may have the category
hierarchy: "pageCategories" : ["Sales > 2017 Black Friday Deals"]. Required
for category-page-view events. At least one of search_query or
page_categories is required for search events. Other event types should not
set this field. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property pageCategories
9313 9314 9315 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9313 def page_categories @page_categories end |
#page_view_id ⇒ String
A unique ID of a web page view. This should be kept the same for all user
events triggered from the same pageview. For example, an item detail page view
could trigger multiple events as the user is browsing the page. The
pageViewId property should be kept the same for all these events so that they
can be grouped together properly. When using the client side event reporting
with JavaScript pixel and Google Tag Manager, this value is filled in
automatically.
Corresponds to the JSON property pageViewId
9324 9325 9326 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9324 def page_view_id @page_view_id end |
#panels ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPanelInfo>
Optional. List of panels associated with this event. Used for panel-level
impression data.
Corresponds to the JSON property panels
9330 9331 9332 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9330 def panels @panels end |
#product_details ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductDetail>
The main product details related to the event. This field is optional except
for the following event types: * add-to-cart * detail-page-view *
purchase-complete In a search event, this field represents the products
returned to the end user on the current page (the end user may have not
finished browsing the whole page yet). When a new page is returned to the end
user, after pagination/filtering/ordering even for the same query, a new
search event with different product_details is desired. The end user may have
not finished browsing the whole page yet.
Corresponds to the JSON property productDetails
9342 9343 9344 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9342 def product_details @product_details end |
#purchase_transaction ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurchaseTransaction
A transaction represents the entire purchase transaction.
Corresponds to the JSON property purchaseTransaction
9347 9348 9349 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9347 def purchase_transaction @purchase_transaction end |
#referrer_uri ⇒ String
The referrer URL of the current page. When using the client side event
reporting with JavaScript pixel and Google Tag Manager, this value is filled
in automatically.
Corresponds to the JSON property referrerUri
9354 9355 9356 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9354 def referrer_uri @referrer_uri end |
#search_query ⇒ String
The user's search query. See SearchRequest.query for definition. The value
must be a UTF-8 encoded string with a length limit of 5,000 characters.
Otherwise, an INVALID_ARGUMENT error is returned. At least one of search_query
or page_categories is required for search events. Other event types should
not set this field. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property searchQuery
9363 9364 9365 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9363 def search_query @search_query end |
#session_id ⇒ String
A unique identifier for tracking a visitor session with a length limit of 128
bytes. A session is an aggregation of an end user behavior in a time span. A
general guideline to populate the session_id: 1. If user has no activity for
30 min, a new session_id should be assigned. 2. The session_id should be
unique across users, suggest use uuid or add visitor_id as prefix.
Corresponds to the JSON property sessionId
9372 9373 9374 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9372 def session_id @session_id end |
#uri ⇒ String
Complete URL (window.location.href) of the user's current page. When using the
client side event reporting with JavaScript pixel and Google Tag Manager, this
value is filled in automatically. Maximum length 5,000 characters.
Corresponds to the JSON property uri
9379 9380 9381 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9379 def uri @uri end |
#user_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaUserInfo
Information of an end user.
Corresponds to the JSON property userInfo
9384 9385 9386 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9384 def user_info @user_info end |
#visitor_id ⇒ String
Required. A unique identifier for tracking visitors. For example, this could
be implemented with an HTTP cookie, which should be able to uniquely identify
a visitor on a single device. This unique identifier should not change if the
visitor log in/out of the website. Don't set the field to the same fixed ID
for different users. This mixes the event history of those users together,
which results in degraded model quality. The field must be a UTF-8 encoded
string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT
error is returned. The field should not contain PII or user-data. We recommend
to use Google Analytics Client ID for this field.
Corresponds to the JSON property visitorId
9398 9399 9400 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9398 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9405 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @cart_id = args[:cart_id] if args.key?(:cart_id) @completion_detail = args[:completion_detail] if args.key?(:completion_detail) @entity = args[:entity] if args.key?(:entity) @event_time = args[:event_time] if args.key?(:event_time) @event_type = args[:event_type] if args.key?(:event_type) @experiment_ids = args[:experiment_ids] if args.key?(:experiment_ids) @filter = args[:filter] if args.key?(:filter) @offset = args[:offset] if args.key?(:offset) @order_by = args[:order_by] if args.key?(:order_by) @page_categories = args[:page_categories] if args.key?(:page_categories) @page_view_id = args[:page_view_id] if args.key?(:page_view_id) @panels = args[:panels] if args.key?(:panels) @product_details = args[:product_details] if args.key?(:product_details) @purchase_transaction = args[:purchase_transaction] if args.key?(:purchase_transaction) @referrer_uri = args[:referrer_uri] if args.key?(:referrer_uri) @search_query = args[:search_query] if args.key?(:search_query) @session_id = args[:session_id] if args.key?(:session_id) @uri = args[:uri] if args.key?(:uri) @user_info = args[:user_info] if args.key?(:user_info) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |