Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaExportAnalyticsMetricsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning. Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaExportAnalyticsMetricsResponse

Returns a new instance of GoogleCloudRetailV2betaExportAnalyticsMetricsResponse.



9740
9741
9742
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2alpha::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



9727
9728
9729
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9727

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2betaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



9732
9733
9734
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9732

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2betaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



9738
9739
9740
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9738

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9745
9746
9747
9748
9749
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9745

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end