Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Metadata related to the progress of the Import operation. This is returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportMetadata

Returns a new instance of GoogleCloudRetailV2betaImportMetadata.



9918
9919
9920
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


9887
9888
9889
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9887

def create_time
  @create_time
end

#failure_countFixnum

Count of entries that encountered errors while processing. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


9892
9893
9894
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9892

def failure_count
  @failure_count
end

#notification_pubsub_topicString

Pub/Sub topic for receiving notification. If this field is set, when the import is finished, a notification is sent to specified Pub/Sub topic. The message data is JSON string of a Operation. Format of the Pub/Sub topic is projects/project/topics/topic`. Corresponds to the JSON propertynotificationPubsubTopic`

Returns:

  • (String)


9900
9901
9902
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9900

def notification_pubsub_topic
  @notification_pubsub_topic
end

#request_idString

Deprecated. This field is never set. Corresponds to the JSON property requestId

Returns:

  • (String)


9905
9906
9907
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9905

def request_id
  @request_id
end

#success_countFixnum

Count of entries that were processed successfully. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


9910
9911
9912
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9910

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


9916
9917
9918
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9916

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9923
9924
9925
9926
9927
9928
9929
9930
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9923

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @notification_pubsub_topic = args[:notification_pubsub_topic] if args.key?(:notification_pubsub_topic)
  @request_id = args[:request_id] if args.key?(:request_id)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end