Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaImportUserEventsResponse.



10032
10033
10034
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2alpha::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



10019
10020
10021
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10019

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



10024
10025
10026
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10024

def errors_config
  @errors_config
end

#import_summaryGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2betaUserEventImportSummary

A summary of import result. The UserEventImportSummary summarizes the import status for user events. Corresponds to the JSON property importSummary



10030
10031
10032
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10030

def import_summary
  @import_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10037
10038
10039
10040
10041
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10037

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @import_summary = args[:import_summary] if args.key?(:import_summary)
end