Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaOutputResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Output result that stores the information about where the exported data is stored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaOutputResult

Returns a new instance of GoogleCloudRetailV2betaOutputResult.



10218
10219
10220
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_resultArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaBigQueryOutputResult>

The BigQuery location where the result is stored. Corresponds to the JSON property bigqueryResult



10211
10212
10213
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10211

def bigquery_result
  @bigquery_result
end

#gcs_resultArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaGcsOutputResult>

The Google Cloud Storage location where the result is stored. Corresponds to the JSON property gcsResult



10216
10217
10218
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10216

def gcs_result
  @gcs_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10223
10224
10225
10226
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10223

def update!(**args)
  @bigquery_result = args[:bigquery_result] if args.key?(:bigquery_result)
  @gcs_result = args[:gcs_result] if args.key?(:gcs_result)
end