Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaPurgeUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the PurgeUserEventsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaPurgeUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaPurgeUserEventsResponse.



10369
10370
10371
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purged_events_countFixnum

The total count of events purged as a result of the operation. Corresponds to the JSON property purgedEventsCount

Returns:

  • (Fixnum)


10367
10368
10369
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10367

def purged_events_count
  @purged_events_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10374
10375
10376
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10374

def update!(**args)
  @purged_events_count = args[:purged_events_count] if args.key?(:purged_events_count)
end