Class: Google::Apis::RetailV2alpha::GoogleLongrunningListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleLongrunningListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::RetailV2alpha::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
constructor
A new instance of GoogleLongrunningListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
Returns a new instance of GoogleLongrunningListOperationsResponse.
10536 10537 10538 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
10521 10522 10523 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10521 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::RetailV2alpha::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
10526 10527 10528 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10526 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
10534 10535 10536 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10534 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10541 10542 10543 10544 10545 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10541 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |