Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalog
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCatalog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
The catalog configuration.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#merchant_center_linking_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaMerchantCenterLinkingConfig
Configures Merchant Center linking.
-
#name ⇒ String
Required.
-
#product_level_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductLevelConfig
Configures what level the product should be uploaded with regards to how users will be send events and how predictions will be made.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalog
constructor
A new instance of GoogleCloudRetailV2alphaCatalog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCatalog
Returns a new instance of GoogleCloudRetailV2alphaCatalog.
1912 1913 1914 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. Immutable. The catalog display name. This field must be a UTF-8
encoded string with a length limit of 128 characters. Otherwise, an
INVALID_ARGUMENT error is returned.
Corresponds to the JSON property displayName
1893 1894 1895 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1893 def display_name @display_name end |
#merchant_center_linking_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaMerchantCenterLinkingConfig
Configures Merchant Center linking. Links contained in the config will be used
to sync data from a Merchant Center account to a Cloud Retail branch.
Corresponds to the JSON property merchantCenterLinkingConfig
1899 1900 1901 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1899 def merchant_center_linking_config @merchant_center_linking_config end |
#name ⇒ String
Required. Immutable. The fully qualified resource name of the catalog.
Corresponds to the JSON property name
1904 1905 1906 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1904 def name @name end |
#product_level_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductLevelConfig
Configures what level the product should be uploaded with regards to how users
will be send events and how predictions will be made.
Corresponds to the JSON property productLevelConfig
1910 1911 1912 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1910 def product_level_config @product_level_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1917 1918 1919 1920 1921 1922 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 1917 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @merchant_center_linking_config = args[:merchant_center_linking_config] if args.key?(:merchant_center_linking_config) @name = args[:name] if args.key?(:name) @product_level_config = args[:product_level_config] if args.key?(:product_level_config) end |