Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Resource that represents completion results.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCustomAttribute>
Custom attributes for the suggestion term.
-
#facets ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseFacet>
Facet information for the suggestion term.
-
#suggestion ⇒ String
The suggestion for the query.
-
#total_product_count ⇒ Fixnum
Total number of products associated with a search with this suggestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult
constructor
A new instance of GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult
Returns a new instance of GoogleCloudRetailV2alphaCompleteQueryResponseCompletionResult.
2432 2433 2434 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCustomAttribute>
Custom attributes for the suggestion term. * For user-data, the attributes
are additional custom attributes ingested through BigQuery. * For cloud-
retail, the attributes are product attributes generated by Cloud Retail. It
requires UserEvent.product_details is imported properly.
Corresponds to the JSON property attributes
2410 2411 2412 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2410 def attributes @attributes end |
#facets ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseFacet>
Facet information for the suggestion term. Gives the number of items resulting
from a search with this suggestion term for each facet. This is an
experimental feature for limited customers. If you want to receive this facet
information, reach out to the Retail support team.
Corresponds to the JSON property facets
2418 2419 2420 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2418 def facets @facets end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
2423 2424 2425 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2423 def suggestion @suggestion end |
#total_product_count ⇒ Fixnum
Total number of products associated with a search with this suggestion. This
is an experimental feature for limited customers. If you want to receive this
product count information, reach out to the Retail support team.
Corresponds to the JSON property totalProductCount
2430 2431 2432 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2430 def total_product_count @total_product_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2437 2438 2439 2440 2441 2442 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2437 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @facets = args[:facets] if args.key?(:facets) @suggestion = args[:suggestion] if args.key?(:suggestion) @total_product_count = args[:total_product_count] if args.key?(:total_product_count) end |