Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Catalog level autocomplete config for customers to customize autocomplete feature's settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaCompletionConfig

Returns a new instance of GoogleCloudRetailV2alphaCompletionConfig.



2543
2544
2545
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2543

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowlist_input_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property allowlistInputConfig



2472
2473
2474
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2472

def allowlist_input_config
  @allowlist_input_config
end

#auto_learningBoolean Also known as: auto_learning?

If set to true, the auto learning function is enabled. Auto learning uses user data to generate suggestions using ML techniques. Default value is false. Only after enabling auto learning can users use cloud-retail data in CompleteQueryRequest. Corresponds to the JSON property autoLearning

Returns:

  • (Boolean)


2480
2481
2482
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2480

def auto_learning
  @auto_learning
end

#denylist_input_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property denylistInputConfig



2486
2487
2488
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2486

def denylist_input_config
  @denylist_input_config
end

#last_allowlist_import_operationString

Output only. Name of the LRO corresponding to the latest allowlist import. Can use GetOperation API to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastAllowlistImportOperation

Returns:

  • (String)


2493
2494
2495
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2493

def last_allowlist_import_operation
  @last_allowlist_import_operation
end

#last_denylist_import_operationString

Output only. Name of the LRO corresponding to the latest denylist import. Can use GetOperation API to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastDenylistImportOperation

Returns:

  • (String)


2500
2501
2502
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2500

def last_denylist_import_operation
  @last_denylist_import_operation
end

#last_suggestions_import_operationString

Output only. Name of the LRO corresponding to the latest suggestion terms list import. Can use GetOperation API method to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastSuggestionsImportOperation

Returns:

  • (String)


2507
2508
2509
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2507

def last_suggestions_import_operation
  @last_suggestions_import_operation
end

#matching_orderString

Specifies the matching order for autocomplete suggestions, e.g., a query consisting of 'sh' with 'out-of-order' specified would suggest "women's shoes", whereas a query of 'red s' with 'exact-prefix' specified would suggest "red shoes". Currently supported values: * 'out-of-order' * 'exact-prefix' Default value: 'exact-prefix'. Corresponds to the JSON property matchingOrder

Returns:

  • (String)


2516
2517
2518
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2516

def matching_order
  @matching_order
end

#max_suggestionsFixnum

The maximum number of autocomplete suggestions returned per term. Default value is 20. If left unset or set to 0, then will fallback to default value. Value range is 1 to 20. Corresponds to the JSON property maxSuggestions

Returns:

  • (Fixnum)


2523
2524
2525
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2523

def max_suggestions
  @max_suggestions
end

#min_prefix_lengthFixnum

The minimum number of characters needed to be typed in order to get suggestions. Default value is 2. If left unset or set to 0, then will fallback to default value. Value range is 1 to 20. Corresponds to the JSON property minPrefixLength

Returns:

  • (Fixnum)


2530
2531
2532
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2530

def min_prefix_length
  @min_prefix_length
end

#nameString

Required. Immutable. Fully qualified name projects/*/locations/*/catalogs/*/ completionConfig Corresponds to the JSON property name

Returns:

  • (String)


2536
2537
2538
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2536

def name
  @name
end

#suggestions_input_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property suggestionsInputConfig



2541
2542
2543
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2541

def suggestions_input_config
  @suggestions_input_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2548

def update!(**args)
  @allowlist_input_config = args[:allowlist_input_config] if args.key?(:allowlist_input_config)
  @auto_learning = args[:auto_learning] if args.key?(:auto_learning)
  @denylist_input_config = args[:denylist_input_config] if args.key?(:denylist_input_config)
  @last_allowlist_import_operation = args[:last_allowlist_import_operation] if args.key?(:last_allowlist_import_operation)
  @last_denylist_import_operation = args[:last_denylist_import_operation] if args.key?(:last_denylist_import_operation)
  @last_suggestions_import_operation = args[:last_suggestions_import_operation] if args.key?(:last_suggestions_import_operation)
  @matching_order = args[:matching_order] if args.key?(:matching_order)
  @max_suggestions = args[:max_suggestions] if args.key?(:max_suggestions)
  @min_prefix_length = args[:min_prefix_length] if args.key?(:min_prefix_length)
  @name = args[:name] if args.key?(:name)
  @suggestions_input_config = args[:suggestions_input_config] if args.key?(:suggestions_input_config)
end