Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchCustomizationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

The public proto to represent the conversational search customization config. It will be converted to the internal proto in the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchCustomizationConfig

Returns a new instance of GoogleCloudRetailV2alphaConversationalSearchCustomizationConfig.



2796
2797
2798
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalogString

Required. Resource name of the catalog. Format: projects/project/locations/ location/catalogs/catalog Corresponds to the JSON property catalog

Returns:

  • (String)


2782
2783
2784
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2782

def catalog
  @catalog
end

#intent_classification_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfig

The public proto to represent the intent classification config. It will be converted to the internal proto in the backend. Corresponds to the JSON property intentClassificationConfig



2788
2789
2790
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2788

def intent_classification_config
  @intent_classification_config
end

#retailer_display_nameString

Optional. The retailer's display name that could be used in our LLM answers. Example - "Google" Corresponds to the JSON property retailerDisplayName

Returns:

  • (String)


2794
2795
2796
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2794

def retailer_display_name
  @retailer_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2801
2802
2803
2804
2805
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2801

def update!(**args)
  @catalog = args[:catalog] if args.key?(:catalog)
  @intent_classification_config = args[:intent_classification_config] if args.key?(:intent_classification_config)
  @retailer_display_name = args[:retailer_display_name] if args.key?(:retailer_display_name)
end