Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchRequestSearchParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Search parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchRequestSearchParams

Returns a new instance of GoogleCloudRetailV2alphaConversationalSearchRequestSearchParams.



2974
2975
2976
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpec

Boost specification to boost certain items. Corresponds to the JSON property boostSpec



2954
2955
2956
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2954

def boost_spec
  @boost_spec
end

#canonical_filterString

Optional. The canonical filter string to restrict search results. The syntax of the canonical filter string is the same as SearchRequest.canonical_filter. Corresponds to the JSON property canonicalFilter

Returns:

  • (String)


2960
2961
2962
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2960

def canonical_filter
  @canonical_filter
end

#filterString

Optional. The filter string to restrict search results. The syntax of the filter string is the same as SearchRequest.filter. Corresponds to the JSON property filter

Returns:

  • (String)


2966
2967
2968
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2966

def filter
  @filter
end

#sort_byString

Optional. The sort string to specify the sorting of search results. The syntax of the sort string is the same as SearchRequest.order_by. Corresponds to the JSON property sortBy

Returns:

  • (String)


2972
2973
2974
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2972

def sort_by
  @sort_by
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2979
2980
2981
2982
2983
2984
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 2979

def update!(**args)
  @boost_spec = args[:boost_spec] if args.key?(:boost_spec)
  @canonical_filter = args[:canonical_filter] if args.key?(:canonical_filter)
  @filter = args[:filter] if args.key?(:filter)
  @sort_by = args[:sort_by] if args.key?(:sort_by)
end