Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswer
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
This field specifies the current user answer during the conversational filtering search. This can be either user selected from suggested answers or user input plain text.
Instance Attribute Summary collapse
-
#selected_answer ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswerSelectedAnswer
This field specifies the selected answers during the conversational search.
-
#text_answer ⇒ String
This field specifies the incremental input text from the user during the conversational search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswer
constructor
A new instance of GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswer
Returns a new instance of GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswer.
3032 3033 3034 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#selected_answer ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaConversationalSearchRequestUserAnswerSelectedAnswer
This field specifies the selected answers during the conversational search.
Corresponds to the JSON property selectedAnswer
3024 3025 3026 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3024 def selected_answer @selected_answer end |
#text_answer ⇒ String
This field specifies the incremental input text from the user during the
conversational search.
Corresponds to the JSON property textAnswer
3030 3031 3032 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3030 def text_answer @text_answer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3037 3038 3039 3040 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3037 def update!(**args) @selected_answer = args[:selected_answer] if args.key?(:selected_answer) @text_answer = args[:text_answer] if args.key?(:text_answer) end |