Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning. Operations.response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExportErrorsConfig
Configuration of destination for Export related errors.
-
#output_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaOutputResult
Output result that stores the information about where the exported data is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
constructor
A new instance of GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
Returns a new instance of GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse.
3502 3503 3504 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3502 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
3489 3490 3491 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3489 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExportErrorsConfig
Configuration of destination for Export related errors.
Corresponds to the JSON property errorsConfig
3494 3495 3496 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3494 def errors_config @errors_config end |
#output_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaOutputResult
Output result that stores the information about where the exported data is
stored.
Corresponds to the JSON property outputResult
3500 3501 3502 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3500 def output_result @output_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3507 3508 3509 3510 3511 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3507 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @output_result = args[:output_result] if args.key?(:output_result) end |