Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the ExportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportProductsResponse

Returns a new instance of GoogleCloudRetailV2alphaExportProductsResponse.



3610
3611
3612
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2alpha::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



3597
3598
3599
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3597

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



3602
3603
3604
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3602

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



3608
3609
3610
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3608

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3615
3616
3617
3618
3619
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3615

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end