Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaFulfillmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaFulfillmentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Fulfillment information, such as the store IDs for in-store pickup or region IDs for different shipping methods.
Instance Attribute Summary collapse
-
#place_ids ⇒ Array<String>
The IDs for this type, such as the store IDs for FulfillmentInfo.type.pickup- in-store or the region IDs for FulfillmentInfo.type.same-day-delivery.
-
#type ⇒ String
The fulfillment type, including commonly used types (such as pickup in store and same day delivery), and custom types.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaFulfillmentInfo
constructor
A new instance of GoogleCloudRetailV2alphaFulfillmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaFulfillmentInfo
Returns a new instance of GoogleCloudRetailV2alphaFulfillmentInfo.
3705 3706 3707 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_ids ⇒ Array<String>
The IDs for this type, such as the store IDs for FulfillmentInfo.type.pickup-
in-store or the region IDs for FulfillmentInfo.type.same-day-delivery. A
maximum of 3000 values are allowed. Each value must be a string with a length
limit of 30 characters, matching the pattern [a-zA-Z0-9_-]+, such as "store1"
or "REGION-2". Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property placeIds
3692 3693 3694 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3692 def place_ids @place_ids end |
#type ⇒ String
The fulfillment type, including commonly used types (such as pickup in store
and same day delivery), and custom types. Customers have to map custom types
to their display names before rendering UI. Supported values: * "pickup-in-
store" * "ship-to-store" * "same-day-delivery" * "next-day-delivery" * "custom-
type-1" * "custom-type-2" * "custom-type-3" * "custom-type-4" * "custom-type-5"
If this field is set to an invalid value other than these, an
INVALID_ARGUMENT error is returned.
Corresponds to the JSON property type
3703 3704 3705 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3703 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3710 3711 3712 3713 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3710 def update!(**args) @place_ids = args[:place_ids] if args.key?(:place_ids) @type = args[:type] if args.key?(:type) end |