Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaGenerativeQuestionConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaGenerativeQuestionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Configuration for a single generated question.
Instance Attribute Summary collapse
-
#allowed_in_conversation ⇒ Boolean
(also: #allowed_in_conversation?)
Optional.
-
#catalog ⇒ String
Required.
-
#example_values ⇒ Array<String>
Output only.
-
#facet ⇒ String
Required.
-
#final_question ⇒ String
Optional.
-
#frequency ⇒ Float
Output only.
-
#generated_question ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaGenerativeQuestionConfig
constructor
A new instance of GoogleCloudRetailV2alphaGenerativeQuestionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaGenerativeQuestionConfig
Returns a new instance of GoogleCloudRetailV2alphaGenerativeQuestionConfig.
3817 3818 3819 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_in_conversation ⇒ Boolean Also known as: allowed_in_conversation?
Optional. Whether the question is asked at serving time.
Corresponds to the JSON property allowedInConversation
3782 3783 3784 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3782 def allowed_in_conversation @allowed_in_conversation end |
#catalog ⇒ String
Required. Resource name of the catalog. Format: projects/project/locations/
location/catalogs/catalog
Corresponds to the JSON property catalog
3789 3790 3791 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3789 def catalog @catalog end |
#example_values ⇒ Array<String>
Output only. Values that can be used to answer the question.
Corresponds to the JSON property exampleValues
3794 3795 3796 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3794 def example_values @example_values end |
#facet ⇒ String
Required. The facet to which the question is associated.
Corresponds to the JSON property facet
3799 3800 3801 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3799 def facet @facet end |
#final_question ⇒ String
Optional. The question that will be used at serving time. Question can have a
max length of 300 bytes. When not populated, generated_question should be used.
Corresponds to the JSON property finalQuestion
3805 3806 3807 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3805 def final_question @final_question end |
#frequency ⇒ Float
Output only. The ratio of how often a question was asked.
Corresponds to the JSON property frequency
3810 3811 3812 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3810 def frequency @frequency end |
#generated_question ⇒ String
Output only. The LLM generated question.
Corresponds to the JSON property generatedQuestion
3815 3816 3817 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3815 def generated_question @generated_question end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3822 3823 3824 3825 3826 3827 3828 3829 3830 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3822 def update!(**args) @allowed_in_conversation = args[:allowed_in_conversation] if args.key?(:allowed_in_conversation) @catalog = args[:catalog] if args.key?(:catalog) @example_values = args[:example_values] if args.key?(:example_values) @facet = args[:facet] if args.key?(:facet) @final_question = args[:final_question] if args.key?(:final_question) @frequency = args[:frequency] if args.key?(:frequency) @generated_question = args[:generated_question] if args.key?(:generated_question) end |