Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImage
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Product image. Recommendations AI and Retail Search use product images to improve prediction and search results. Product images can be returned in results, and are shown in prediction or search previews in the console. Please try to provide correct product images and avoid using images with size too small.
Instance Attribute Summary collapse
-
#height ⇒ Fixnum
Height of the image in number of pixels.
-
#uri ⇒ String
Required.
-
#width ⇒ Fixnum
Width of the image in number of pixels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImage
constructor
A new instance of GoogleCloudRetailV2alphaImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImage
Returns a new instance of GoogleCloudRetailV2alphaImage.
3929 3930 3931 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#height ⇒ Fixnum
Height of the image in number of pixels. This field must be nonnegative.
Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property height
3912 3913 3914 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3912 def height @height end |
#uri ⇒ String
Required. URI of the image. This field must be a valid UTF-8 encoded URI with
a length limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is
returned. Google Merchant Center property image_link. Schema.org property Product.image.
Corresponds to the JSON property uri
3921 3922 3923 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3921 def uri @uri end |
#width ⇒ Fixnum
Width of the image in number of pixels. This field must be nonnegative.
Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property width
3927 3928 3929 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3927 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3934 3935 3936 3937 3938 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3934 def update!(**args) @height = args[:height] if args.key?(:height) @uri = args[:uri] if args.key?(:uri) @width = args[:width] if args.key?(:width) end |