Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportCompletionDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the ImportCompletionDataRequest. If the long running operation is done, this message is returned by the google.longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportCompletionDataResponse

Returns a new instance of GoogleCloudRetailV2alphaImportCompletionDataResponse.



3980
3981
3982
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2alpha::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



3978
3979
3980
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3978

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3985
3986
3987
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 3985

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end