Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportErrorsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Configuration of destination for Import related errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportErrorsConfig

Returns a new instance of GoogleCloudRetailV2alphaImportErrorsConfig.



4002
4003
4004
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_prefixString

Google Cloud Storage prefix for import errors. This must be an empty, existing Cloud Storage directory. Import errors are written to sharded files in this directory, one per line, as a JSON-encoded google.rpc.Status message. Corresponds to the JSON property gcsPrefix

Returns:

  • (String)


4000
4001
4002
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4000

def gcs_prefix
  @gcs_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4007
4008
4009
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4007

def update!(**args)
  @gcs_prefix = args[:gcs_prefix] if args.key?(:gcs_prefix)
end