Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportUserEventsResponse

Returns a new instance of GoogleCloudRetailV2alphaImportUserEventsResponse.



4216
4217
4218
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2alpha::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4203
4204
4205
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4203

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



4208
4209
4210
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4208

def errors_config
  @errors_config
end

#import_summaryGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaUserEventImportSummary

A summary of import result. The UserEventImportSummary summarizes the import status for user events. Corresponds to the JSON property importSummary



4214
4215
4216
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4214

def import_summary
  @import_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4221
4222
4223
4224
4225
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4221

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @import_summary = args[:import_summary] if args.key?(:import_summary)
end