Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
The public proto to represent the intent classification config. It will be converted to the internal proto in the backend.
Instance Attribute Summary collapse
-
#blocklist_keywords ⇒ Array<String>
Optional.
-
#disabled_intent_types ⇒ Array<String>
Optional.
-
#example ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfigExample>
Optional.
-
#inline_source ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfigInlineSource
Inline source for intent classifications.
-
#model_preamble ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaIntentClassificationConfig
constructor
A new instance of GoogleCloudRetailV2alphaIntentClassificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaIntentClassificationConfig
Returns a new instance of GoogleCloudRetailV2alphaIntentClassificationConfig.
4263 4264 4265 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4263 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocklist_keywords ⇒ Array<String>
Optional. A list of keywords that will be used to classify the query to the "
BLOCKLISTED" intent type. The keywords are case insensitive.
Corresponds to the JSON property blocklistKeywords
4236 4237 4238 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4236 def blocklist_keywords @blocklist_keywords end |
#disabled_intent_types ⇒ Array<String>
Optional. A list of intent types that will be disabled for this customer. The
intent types must match one of the predefined intent types defined at https://
cloud.google.com/retail/docs/reference/rpc/google.cloud.retail.v2alpha#
querytype
Corresponds to the JSON property disabledIntentTypes
4244 4245 4246 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4244 def disabled_intent_types @disabled_intent_types end |
#example ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfigExample>
Optional. A list of examples for intent classification.
Corresponds to the JSON property example
4249 4250 4251 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4249 def example @example end |
#inline_source ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaIntentClassificationConfigInlineSource
Inline source for intent classifications.
Corresponds to the JSON property inlineSource
4254 4255 4256 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4254 def inline_source @inline_source end |
#model_preamble ⇒ String
Optional. Customers can use the preamble to specify any requirements for
blocklisting intent classification. This preamble will be added to the
blocklisting intent classification model prompt.
Corresponds to the JSON property modelPreamble
4261 4262 4263 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4261 def model_preamble @model_preamble end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4268 4269 4270 4271 4272 4273 4274 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 4268 def update!(**args) @blocklist_keywords = args[:blocklist_keywords] if args.key?(:blocklist_keywords) @disabled_intent_types = args[:disabled_intent_types] if args.key?(:disabled_intent_types) @example = args[:example] if args.key?(:example) @inline_source = args[:inline_source] if args.key?(:inline_source) @model_preamble = args[:model_preamble] if args.key?(:model_preamble) end |