Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
The PageOptimizationConfig for model training. This determines how many panels to optimize for, and which serving configs to consider for each panel. The purpose of this model is to optimize which ServingConfig to show on which panels in way that optimizes the visitors shopping journey.
Instance Attribute Summary collapse
-
#page_optimization_event_type ⇒ String
Required.
-
#panels ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfigPanel>
Required.
-
#restriction ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaModelPageOptimizationConfig
constructor
A new instance of GoogleCloudRetailV2alphaModelPageOptimizationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaModelPageOptimizationConfig
Returns a new instance of GoogleCloudRetailV2alphaModelPageOptimizationConfig.
5257 5258 5259 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_optimization_event_type ⇒ String
Required. The type of UserEvent this page optimization is shown for. Each page
has an associated event type - this will be the corresponding event type for
the page that the page optimization model is used on. Supported types: * add-
to-cart: Products being added to cart. * detail-page-view: Products detail
page viewed. * home-page-view: Homepage viewed * category-page-view:
Homepage viewed * shopping-cart-page-view: User viewing a shopping cart.
home-page-view only allows models with type recommended-for-you. All other
page_optimization_event_type allow all Model.types.
Corresponds to the JSON property pageOptimizationEventType
5243 5244 5245 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5243 def page_optimization_event_type @page_optimization_event_type end |
#panels ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaModelPageOptimizationConfigPanel>
Required. A list of panel configurations. Limit = 5.
Corresponds to the JSON property panels
5248 5249 5250 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5248 def panels @panels end |
#restriction ⇒ String
Optional. How to restrict results across panels e.g. can the same
ServingConfig be shown on multiple panels at once. If unspecified, default to
UNIQUE_MODEL_RESTRICTION.
Corresponds to the JSON property restriction
5255 5256 5257 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5255 def restriction @restriction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5262 5263 5264 5265 5266 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5262 def update!(**args) @page_optimization_event_type = args[:page_optimization_event_type] if args.key?(:page_optimization_event_type) @panels = args[:panels] if args.key?(:panels) @restriction = args[:restriction] if args.key?(:restriction) end |