Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPanelInfo
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPanelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Detailed panel information associated with a user event.
Instance Attribute Summary collapse
-
#attribution_token ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#panel_id ⇒ String
Required.
-
#panel_position ⇒ Fixnum
Optional.
-
#product_details ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductDetail>
Optional.
-
#total_panels ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPanelInfo
constructor
A new instance of GoogleCloudRetailV2alphaPanelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPanelInfo
Returns a new instance of GoogleCloudRetailV2alphaPanelInfo.
5489 5490 5491 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_token ⇒ String
Optional. The attribution token of the panel.
Corresponds to the JSON property attributionToken
5460 5461 5462 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5460 def attribution_token @attribution_token end |
#display_name ⇒ String
Optional. The display name of the panel.
Corresponds to the JSON property displayName
5465 5466 5467 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5465 def display_name @display_name end |
#panel_id ⇒ String
Required. The panel ID.
Corresponds to the JSON property panelId
5470 5471 5472 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5470 def panel_id @panel_id end |
#panel_position ⇒ Fixnum
Optional. The ordered position of the panel, if shown to the user with other
panels. If set, then total_panels must also be set.
Corresponds to the JSON property panelPosition
5476 5477 5478 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5476 def panel_position @panel_position end |
#product_details ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductDetail>
Optional. The product details associated with the panel.
Corresponds to the JSON property productDetails
5481 5482 5483 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5481 def product_details @product_details end |
#total_panels ⇒ Fixnum
Optional. The total number of panels, including this one, shown to the user.
Must be set if panel_position is set.
Corresponds to the JSON property totalPanels
5487 5488 5489 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5487 def total_panels @total_panels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5494 5495 5496 5497 5498 5499 5500 5501 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5494 def update!(**args) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @display_name = args[:display_name] if args.key?(:display_name) @panel_id = args[:panel_id] if args.key?(:panel_id) @panel_position = args[:panel_position] if args.key?(:panel_position) @product_details = args[:product_details] if args.key?(:product_details) @total_panels = args[:total_panels] if args.key?(:total_panels) end |