Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response message for predict method.
Instance Attribute Summary collapse
-
#attribution_token ⇒ String
A unique attribution token.
-
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
-
#results ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponsePredictionResult>
A list of recommended products.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
True if the validateOnly property was set in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPredictResponse
constructor
A new instance of GoogleCloudRetailV2alphaPredictResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPredictResponse
Returns a new instance of GoogleCloudRetailV2alphaPredictResponse.
5702 5703 5704 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_token ⇒ String
A unique attribution token. This should be included in the UserEvent logs
resulting from this recommendation, which enables accurate attribution of
recommendation model performance.
Corresponds to the JSON property attributionToken
5683 5684 5685 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5683 def attribution_token @attribution_token end |
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
Corresponds to the JSON property missingIds
5688 5689 5690 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5688 def missing_ids @missing_ids end |
#results ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPredictResponsePredictionResult>
A list of recommended products. The order represents the ranking (from the
most relevant product to the least).
Corresponds to the JSON property results
5694 5695 5696 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5694 def results @results end |
#validate_only ⇒ Boolean Also known as: validate_only?
True if the validateOnly property was set in the request.
Corresponds to the JSON property validateOnly
5699 5700 5701 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5699 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5707 5708 5709 5710 5711 5712 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5707 def update!(**args) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @missing_ids = args[:missing_ids] if args.key?(:missing_ids) @results = args[:results] if args.key?(:results) @validate_only = args[:validate_only] if args.key?(:validate_only) end |