Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProduct
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProduct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Product captures all metadata information of items to be recommended or searched.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCustomAttribute>
Highly encouraged.
-
#audience ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaAudience
An intended audience of the Product for whom it's sold.
-
#availability ⇒ String
The online availability of the Product.
-
#available_quantity ⇒ Fixnum
The available quantity of the item.
-
#available_time ⇒ String
The timestamp when this Product becomes available for SearchService.Search.
-
#brands ⇒ Array<String>
The brands of the product.
-
#categories ⇒ Array<String>
Product categories.
-
#collection_member_ids ⇒ Array<String>
The id of the collection members when type is Type.COLLECTION.
-
#color_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaColorInfo
The color information of a Product.
-
#conditions ⇒ Array<String>
The condition of the product.
-
#description ⇒ String
Product description.
-
#expire_time ⇒ String
Note that this field is applied in the following ways: * If the Product is already expired when it is uploaded, this product is not indexed for search.
-
#fulfillment_info ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaFulfillmentInfo>
Fulfillment information, such as the store IDs for in-store pickup or region IDs for different shipping methods.
-
#gtin ⇒ String
The Global Trade Item Number (GTIN) of the product.
-
#id ⇒ String
Immutable.
-
#images ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImage>
Product images for the product.
-
#language_code ⇒ String
Language of the title/description and other string attributes.
-
#local_inventories ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaLocalInventory>
Output only.
-
#materials ⇒ Array<String>
The material of the product.
-
#name ⇒ String
Immutable.
-
#patterns ⇒ Array<String>
The pattern or graphic print of the product.
-
#price_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPriceInfo
The price information of a Product.
-
#primary_product_id ⇒ String
Variant group identifier.
-
#promotions ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPromotion>
The promotions applied to the product.
-
#publish_time ⇒ String
The timestamp when the product is published by the retailer for the first time, which indicates the freshness of the products.
-
#rating ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaRating
The rating of a Product.
-
#retrievable_fields ⇒ String
Indicates which fields in the Products are returned in SearchResponse.
-
#sizes ⇒ Array<String>
The size of the product.
-
#tags ⇒ Array<String>
Custom tags associated with the product.
-
#title ⇒ String
Required.
-
#ttl ⇒ String
Input only.
-
#type ⇒ String
Immutable.
-
#uri ⇒ String
Canonical URL directly linking to the product detail page.
-
#variants ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProduct>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaProduct
constructor
A new instance of GoogleCloudRetailV2alphaProduct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaProduct
Returns a new instance of GoogleCloudRetailV2alphaProduct.
6193 6194 6195 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaCustomAttribute>
Highly encouraged. Extra product attributes to be included. For example, for
products, this could include the store name, vendor, style, color, etc. These
are very strong signals for recommendation model, thus we highly recommend
providing the attributes here. Features that can take on one of a limited
number of possible values. Two types of features can be set are: Textual
features. some examples would be the brand/maker of a product, or country of a
customer. Numerical features. Some examples would be the height/weight of a
product, or age of a customer. For example: "vendor": `"text": ["vendor123",
"vendor456"]`, "lengths_cm": `"numbers":[2.3, 15.4]`, "heights_cm": `"numbers"
:[8.1, 6.4]`. This field needs to pass all below criteria, otherwise an
INVALID_ARGUMENT error is returned: * Max entries count: 200. * The key must
be a UTF-8 encoded string with a length limit of 128 characters. * For
indexable attribute, the key must match the pattern: a-zA-Z0-9*. For example,
key0LikeThis or KEY_1_LIKE_THIS. * For text attributes, at most 400
values are allowed. Empty values are not allowed. Each value must be a non-
empty UTF-8 encoded string with a length limit of 256 characters. * For number
attributes, at most 400 values are allowed.
Corresponds to the JSON property attributes
5866 5867 5868 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5866 def attributes @attributes end |
#audience ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaAudience
An intended audience of the Product for whom it's sold.
Corresponds to the JSON property audience
5871 5872 5873 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5871 def audience @audience end |
#availability ⇒ String
The online availability of the Product. Default to Availability.IN_STOCK. For
primary products with variants set the availability of the primary as
Availability.OUT_OF_STOCK and set the true availability at the variant level.
This way the primary product will be considered "in stock" as long as it has
at least one variant in stock. For primary products with no variants set the
true availability at the primary level. Corresponding properties: Google
Merchant Center property availability. Schema.org property Offer.availability.
Corresponds to the JSON property availability
5884 5885 5886 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5884 def availability @availability end |
#available_quantity ⇒ Fixnum
The available quantity of the item.
Corresponds to the JSON property availableQuantity
5889 5890 5891 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5889 def available_quantity @available_quantity end |
#available_time ⇒ String
The timestamp when this Product becomes available for SearchService.Search.
Note that this is only applicable to Type.PRIMARY and Type.COLLECTION, and
ignored for Type.VARIANT.
Corresponds to the JSON property availableTime
5896 5897 5898 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5896 def available_time @available_time end |
#brands ⇒ Array<String>
The brands of the product. A maximum of 30 brands are allowed unless
overridden through the Google Cloud console. Each brand must be a UTF-8
encoded string with a length limit of 1,000 characters. Otherwise, an
INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant
Center property brand.
Schema.org property Product.brand.
Corresponds to the JSON property brands
5906 5907 5908 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5906 def brands @brands end |
#categories ⇒ Array<String>
Product categories. This field is repeated for supporting one product
belonging to several parallel categories. Strongly recommended using the full
path for better search / recommendation quality. To represent full path of
category, use '>' sign to separate different hierarchies. If '>' is part of
the category name, replace it with other character(s). For example, if a shoes
product belongs to both ["Shoes & Accessories" -> "Shoes"] and ["Sports &
Fitness" -> "Athletic Clothing" -> "Shoes"], it could be represented as: "
categories": [ "Shoes & Accessories > Shoes", "Sports & Fitness > Athletic
Clothing > Shoes" ] Must be set for Type.PRIMARY Product otherwise an
INVALID_ARGUMENT error is returned. At most 250 values are allowed per Product
unless overridden through the Google Cloud console. Empty values are not
allowed. Each value must be a UTF-8 encoded string with a length limit of 5,
000 characters. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponding properties: Google Merchant Center property
google_product_category. Schema.org property Product.category. [mc_google_product_category]: https://support.google.com/
merchants/answer/6324436
Corresponds to the JSON property categories
5927 5928 5929 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5927 def categories @categories end |
#collection_member_ids ⇒ Array<String>
The id of the collection members when type is Type.COLLECTION. Non-existent
product ids are allowed. The type of the members must be either Type.PRIMARY
or Type.VARIANT otherwise an INVALID_ARGUMENT error is thrown. Should not set
it for other types. A maximum of 1000 values are allowed. Otherwise, an
INVALID_ARGUMENT error is return.
Corresponds to the JSON property collectionMemberIds
5936 5937 5938 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5936 def collection_member_ids @collection_member_ids end |
#color_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaColorInfo
The color information of a Product.
Corresponds to the JSON property colorInfo
5941 5942 5943 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5941 def color_info @color_info end |
#conditions ⇒ Array<String>
The condition of the product. Strongly encouraged to use the standard values: "
new", "refurbished", "used". A maximum of 1 value is allowed per Product. Each
value must be a UTF-8 encoded string with a length limit of 128 characters.
Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties:
Google Merchant Center property condition. Schema.org property Offer.itemCondition.
Corresponds to the JSON property conditions
5952 5953 5954 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5952 def conditions @conditions end |
#description ⇒ String
Product description. This field must be a UTF-8 encoded string with a length
limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponding properties: Google Merchant Center property description. Schema.org property Product.
description.
Corresponds to the JSON property description
5961 5962 5963 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5961 def description @description end |
#expire_time ⇒ String
Note that this field is applied in the following ways: * If the Product is
already expired when it is uploaded, this product is not indexed for search. *
If the Product is not expired when it is uploaded, only the Type.PRIMARY's and
Type.COLLECTION's expireTime is respected, and Type.VARIANT's expireTime is
not used. In general, we suggest the users to delete the stale products
explicitly, instead of using this field to determine staleness. expire_time
must be later than available_time and publish_time, otherwise an
INVALID_ARGUMENT error is thrown. Corresponding properties: Google Merchant
Center property expiration_date.
Corresponds to the JSON property expireTime
5975 5976 5977 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5975 def expire_time @expire_time end |
#fulfillment_info ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaFulfillmentInfo>
Fulfillment information, such as the store IDs for in-store pickup or region
IDs for different shipping methods. All the elements must have distinct
FulfillmentInfo.type. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property fulfillmentInfo
5982 5983 5984 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5982 def fulfillment_info @fulfillment_info end |
#gtin ⇒ String
The Global Trade Item Number (GTIN) of the product. This field must be a UTF-8
encoded string with a length limit of 128 characters. Otherwise, an
INVALID_ARGUMENT error is returned. This field must be a Unigram. Otherwise,
an INVALID_ARGUMENT error is returned. Corresponding properties: Google
Merchant Center property gtin. Schema.org property Product.isbn,
Product.gtin8, Product.gtin12, Product.gtin13, or Product.gtin14. If the value is not a valid GTIN, an
INVALID_ARGUMENT error is returned.
Corresponds to the JSON property gtin
5996 5997 5998 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 5996 def gtin @gtin end |
#id ⇒ String
Immutable. Product identifier, which is the final component of name. For
example, this field is "id_1", if name is projects/*/locations/global/
catalogs/default_catalog/branches/default_branch/products/id_1. This field
must be a UTF-8 encoded string with a length limit of 128 characters.
Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties:
Google Merchant Center property id. Schema.org property Product.sku.
Corresponds to the JSON property id
6007 6008 6009 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6007 def id @id end |
#images ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaImage>
Product images for the product. We highly recommend putting the main image
first. A maximum of 300 images are allowed. Corresponding properties: Google
Merchant Center property image_link. Schema.org property Product.image.
Corresponds to the JSON property images
6015 6016 6017 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6015 def images @images end |
#language_code ⇒ String
Language of the title/description and other string attributes. Use language
tags defined by BCP 47. For
product prediction, this field is ignored and the model automatically detects
the text language. The Product can include text in different languages, but
duplicating Products to provide text in multiple languages can result in
degraded model performance. For product search this field is in use. It
defaults to "en-US" if unset.
Corresponds to the JSON property languageCode
6026 6027 6028 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6026 def language_code @language_code end |
#local_inventories ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaLocalInventory>
Output only. A list of local inventories specific to different places. This
field can be managed by ProductService.AddLocalInventories and ProductService.
RemoveLocalInventories APIs if fine-grained, high-volume updates are necessary.
Corresponds to the JSON property localInventories
6033 6034 6035 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6033 def local_inventories @local_inventories end |
#materials ⇒ Array<String>
The material of the product. For example, "leather", "wooden". A maximum of 20
values are allowed. Each value must be a UTF-8 encoded string with a length
limit of 200 characters. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponding properties: Google Merchant Center property material. Schema.org property Product.
material.
Corresponds to the JSON property materials
6043 6044 6045 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6043 def materials @materials end |
#name ⇒ String
Immutable. Full resource name of the product, such as projects/*/locations/
global/catalogs/default_catalog/branches/default_branch/products/product_id.
Corresponds to the JSON property name
6049 6050 6051 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6049 def name @name end |
#patterns ⇒ Array<String>
The pattern or graphic print of the product. For example, "striped", "polka
dot", "paisley". A maximum of 20 values are allowed per Product. Each value
must be a UTF-8 encoded string with a length limit of 128 characters.
Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties:
Google Merchant Center property pattern. Schema.org property Product.pattern.
Corresponds to the JSON property patterns
6060 6061 6062 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6060 def patterns @patterns end |
#price_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPriceInfo
The price information of a Product.
Corresponds to the JSON property priceInfo
6065 6066 6067 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6065 def price_info @price_info end |
#primary_product_id ⇒ String
Variant group identifier. Must be an id, with the same parent branch with this
product. Otherwise, an error is thrown. For Type.PRIMARY Products, this field
can only be empty or set to the same value as id. For VARIANT Products, this
field cannot be empty. A maximum of 2,000 products are allowed to share the
same Type.PRIMARY Product. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponding properties: Google Merchant Center property item_group_id. Schema.org property
Product.inProductGroupWithID.
Corresponds to the JSON property primaryProductId
6077 6078 6079 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6077 def primary_product_id @primary_product_id end |
#promotions ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPromotion>
The promotions applied to the product. A maximum of 10 values are allowed per
Product. Only Promotion.promotion_id will be used, other fields will be
ignored if set.
Corresponds to the JSON property promotions
6084 6085 6086 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6084 def promotions @promotions end |
#publish_time ⇒ String
The timestamp when the product is published by the retailer for the first time,
which indicates the freshness of the products. Note that this field is
different from available_time, given it purely describes product freshness
regardless of when it is available on search and recommendation.
Corresponds to the JSON property publishTime
6092 6093 6094 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6092 def publish_time @publish_time end |
#rating ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaRating
The rating of a Product.
Corresponds to the JSON property rating
6097 6098 6099 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6097 def @rating end |
#retrievable_fields ⇒ String
Indicates which fields in the Products are returned in SearchResponse.
Supported fields for all types: * audience * availability * brands *
color_info * conditions * gtin * materials * name * patterns * price_info *
rating * sizes * title * uri Supported fields only for Type.PRIMARY and Type.
COLLECTION: * categories * description * images Supported fields only for Type.
VARIANT: * Only the first image in images To mark attributes as retrievable,
include paths of the form "attributes.key" where "key" is the key of a custom
attribute, as specified in attributes. For Type.PRIMARY and Type.COLLECTION,
the following fields are always returned in SearchResponse by default: * name
For Type.VARIANT, the following fields are always returned in by default: *
name * color_info Note: Returning more fields in SearchResponse can increase
response payload size and serving latency. This field is deprecated. Use the
retrievable site-wide control instead.
Corresponds to the JSON property retrievableFields
6114 6115 6116 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6114 def retrievable_fields @retrievable_fields end |
#sizes ⇒ Array<String>
The size of the product. To represent different size systems or size types,
consider using this format: [[[size_system:]size_type:]size_value]. For
example, in "US:MENS:M", "US" represents size system; "MENS" represents size
type; "M" represents size value. In "GIRLS:27", size system is empty; "GIRLS"
represents size type; "27" represents size value. In "32 inches", both size
system and size type are empty, while size value is "32 inches". A maximum of
20 values are allowed per Product. Each value must be a UTF-8 encoded string
with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is
returned. Corresponding properties: Google Merchant Center property size, size_type, and size_system. Schema.org property Product.
size.
Corresponds to the JSON property sizes
6131 6132 6133 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6131 def sizes @sizes end |
#tags ⇒ Array<String>
Custom tags associated with the product. At most 250 values are allowed per
Product. This value must be a UTF-8 encoded string with a length limit of 1,
000 characters. Otherwise, an INVALID_ARGUMENT error is returned. This tag can
be used for filtering recommendation results by passing the tag as part of the
PredictRequest.filter. Corresponding properties: Google Merchant Center
property custom_label_0–4.
Corresponds to the JSON property tags
6142 6143 6144 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6142 def @tags end |
#title ⇒ String
Required. Product title. This field must be a UTF-8 encoded string with a
length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is
returned. Corresponding properties: Google Merchant Center property title. Schema.org property
Product.name.
Corresponds to the JSON property title
6151 6152 6153 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6151 def title @title end |
#ttl ⇒ String
Input only. The TTL (time to live) of the product. Note that this is only
applicable to Type.PRIMARY and Type.COLLECTION, and ignored for Type.VARIANT.
In general, we suggest the users to delete the stale products explicitly,
instead of using this field to determine staleness. If it is set, it must be a
non-negative value, and expire_time is set as current timestamp plus ttl. The
derived expire_time is returned in the output and ttl is left blank when
retrieving the Product. If it is set, the product is not available for
SearchService.Search after current timestamp plus ttl. However, the product
can still be retrieved by ProductService.GetProduct and ProductService.
ListProducts.
Corresponds to the JSON property ttl
6165 6166 6167 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6165 def ttl @ttl end |
#type ⇒ String
Immutable. The type of the product. Default to Catalog.product_level_config.
ingestion_product_type if unset.
Corresponds to the JSON property type
6171 6172 6173 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6171 def type @type end |
#uri ⇒ String
Canonical URL directly linking to the product detail page. It is strongly
recommended to provide a valid uri for the product, otherwise the service
performance could be significantly degraded. This field must be a UTF-8
encoded string with a length limit of 5,000 characters. Otherwise, an
INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant
Center property link.
Schema.org property Offer.url.
Corresponds to the JSON property uri
6182 6183 6184 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6182 def uri @uri end |
#variants ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProduct>
Output only. Product variants grouped together on primary product which share
similar product attributes. It's automatically grouped by primary_product_id
for all the product variants. Only populated for Type.PRIMARY Products. Note:
This field is OUTPUT_ONLY for ProductService.GetProduct. Do not set this field
in API requests.
Corresponds to the JSON property variants
6191 6192 6193 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6191 def variants @variants end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6198 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @audience = args[:audience] if args.key?(:audience) @availability = args[:availability] if args.key?(:availability) @available_quantity = args[:available_quantity] if args.key?(:available_quantity) @available_time = args[:available_time] if args.key?(:available_time) @brands = args[:brands] if args.key?(:brands) @categories = args[:categories] if args.key?(:categories) @collection_member_ids = args[:collection_member_ids] if args.key?(:collection_member_ids) @color_info = args[:color_info] if args.key?(:color_info) @conditions = args[:conditions] if args.key?(:conditions) @description = args[:description] if args.key?(:description) @expire_time = args[:expire_time] if args.key?(:expire_time) @fulfillment_info = args[:fulfillment_info] if args.key?(:fulfillment_info) @gtin = args[:gtin] if args.key?(:gtin) @id = args[:id] if args.key?(:id) @images = args[:images] if args.key?(:images) @language_code = args[:language_code] if args.key?(:language_code) @local_inventories = args[:local_inventories] if args.key?(:local_inventories) @materials = args[:materials] if args.key?(:materials) @name = args[:name] if args.key?(:name) @patterns = args[:patterns] if args.key?(:patterns) @price_info = args[:price_info] if args.key?(:price_info) @primary_product_id = args[:primary_product_id] if args.key?(:primary_product_id) @promotions = args[:promotions] if args.key?(:promotions) @publish_time = args[:publish_time] if args.key?(:publish_time) @rating = args[:rating] if args.key?(:rating) @retrievable_fields = args[:retrievable_fields] if args.key?(:retrievable_fields) @sizes = args[:sizes] if args.key?(:sizes) @tags = args[:tags] if args.key?(:tags) @title = args[:title] if args.key?(:title) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @uri = args[:uri] if args.key?(:uri) @variants = args[:variants] if args.key?(:variants) end |