Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaProductAttributeValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Product attribute which structured by an attribute name and value. This structure is used in conversational search filters and answers. For example, if we have name=color and value=red, this means that the color is red.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaProductAttributeValue

Returns a new instance of GoogleCloudRetailV2alphaProductAttributeValue.



6277
6278
6279
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The attribute name. Corresponds to the JSON property name

Returns:

  • (String)


6270
6271
6272
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6270

def name
  @name
end

#valueString

The attribute value. Corresponds to the JSON property value

Returns:

  • (String)


6275
6276
6277
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6275

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6282
6283
6284
6285
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6282

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end