Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurchaseTransaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

A transaction represents the entire purchase transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurchaseTransaction

Returns a new instance of GoogleCloudRetailV2alphaPurchaseTransaction.



6498
6499
6500
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#costFloat

All the costs associated with the products. These can be manufacturing costs, shipping expenses not borne by the end user, or any other costs, such that: * Profit = revenue - tax - cost Corresponds to the JSON property cost

Returns:

  • (Float)


6474
6475
6476
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6474

def cost
  @cost
end

#currency_codeString

Required. Currency code. Use three-character ISO-4217 code. Corresponds to the JSON property currencyCode

Returns:

  • (String)


6479
6480
6481
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6479

def currency_code
  @currency_code
end

#idString

The transaction ID with a length limit of 128 characters. Corresponds to the JSON property id

Returns:

  • (String)


6484
6485
6486
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6484

def id
  @id
end

#revenueFloat

Required. Total non-zero revenue or grand total associated with the transaction. This value include shipping, tax, or other adjustments to total revenue that you want to include as part of your revenue calculations. Corresponds to the JSON property revenue

Returns:

  • (Float)


6491
6492
6493
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6491

def revenue
  @revenue
end

#taxFloat

All the taxes associated with the transaction. Corresponds to the JSON property tax

Returns:

  • (Float)


6496
6497
6498
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6496

def tax
  @tax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6503
6504
6505
6506
6507
6508
6509
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6503

def update!(**args)
  @cost = args[:cost] if args.key?(:cost)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @id = args[:id] if args.key?(:id)
  @revenue = args[:revenue] if args.key?(:revenue)
  @tax = args[:tax] if args.key?(:tax)
end