Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurchaseTransaction
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPurchaseTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
A transaction represents the entire purchase transaction.
Instance Attribute Summary collapse
-
#cost ⇒ Float
All the costs associated with the products.
-
#currency_code ⇒ String
Required.
-
#id ⇒ String
The transaction ID with a length limit of 128 characters.
-
#revenue ⇒ Float
Required.
-
#tax ⇒ Float
All the taxes associated with the transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurchaseTransaction
constructor
A new instance of GoogleCloudRetailV2alphaPurchaseTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaPurchaseTransaction
Returns a new instance of GoogleCloudRetailV2alphaPurchaseTransaction.
6497 6498 6499 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost ⇒ Float
All the costs associated with the products. These can be manufacturing costs,
shipping expenses not borne by the end user, or any other costs, such that: *
Profit = revenue - tax - cost
Corresponds to the JSON property cost
6473 6474 6475 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6473 def cost @cost end |
#currency_code ⇒ String
Required. Currency code. Use three-character ISO-4217 code.
Corresponds to the JSON property currencyCode
6478 6479 6480 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6478 def currency_code @currency_code end |
#id ⇒ String
The transaction ID with a length limit of 128 characters.
Corresponds to the JSON property id
6483 6484 6485 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6483 def id @id end |
#revenue ⇒ Float
Required. Total non-zero revenue or grand total associated with the
transaction. This value include shipping, tax, or other adjustments to total
revenue that you want to include as part of your revenue calculations.
Corresponds to the JSON property revenue
6490 6491 6492 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6490 def revenue @revenue end |
#tax ⇒ Float
All the taxes associated with the transaction.
Corresponds to the JSON property tax
6495 6496 6497 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6495 def tax @tax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6502 6503 6504 6505 6506 6507 6508 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 6502 def update!(**args) @cost = args[:cost] if args.key?(:cost) @currency_code = args[:currency_code] if args.key?(:currency_code) @id = args[:id] if args.key?(:id) @revenue = args[:revenue] if args.key?(:revenue) @tax = args[:tax] if args.key?(:tax) end |