Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSafetySetting
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSafetySetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Safety settings.
Instance Attribute Summary collapse
-
#category ⇒ String
Harm category.
-
#method_prop ⇒ String
Optional.
-
#threshold ⇒ String
The harm block threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSafetySetting
constructor
A new instance of GoogleCloudRetailV2alphaSafetySetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSafetySetting
Returns a new instance of GoogleCloudRetailV2alphaSafetySetting.
7534 7535 7536 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Harm category.
Corresponds to the JSON property category
7521 7522 7523 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7521 def category @category end |
#method_prop ⇒ String
Optional. Specify if the threshold is used for probability or severity score.
If not specified, the threshold is used for probability score.
Corresponds to the JSON property method
7527 7528 7529 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7527 def method_prop @method_prop end |
#threshold ⇒ String
The harm block threshold.
Corresponds to the JSON property threshold
7532 7533 7534 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7532 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7539 7540 7541 7542 7543 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7539 def update!(**args) @category = args[:category] if args.key?(:category) @method_prop = args[:method_prop] if args.key?(:method_prop) @threshold = args[:threshold] if args.key?(:threshold) end |