Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaSafetySetting

Returns a new instance of GoogleCloudRetailV2alphaSafetySetting.



7532
7533
7534
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Harm category. Corresponds to the JSON property category

Returns:

  • (String)


7519
7520
7521
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7519

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


7525
7526
7527
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7525

def method_prop
  @method_prop
end

#thresholdString

The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


7530
7531
7532
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7530

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7537
7538
7539
7540
7541
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7537

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end