Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Boost applies to products which match a condition.
Instance Attribute Summary collapse
-
#boost ⇒ Float
Strength of the condition boost, which should be in [-1, 1].
-
#condition ⇒ String
An expression which specifies a boost condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec
constructor
A new instance of GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec
Returns a new instance of GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec.
7890 7891 7892 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost ⇒ Float
Strength of the condition boost, which should be in [-1, 1]. Negative boost
means demotion. Default is 0.0. Setting to 1.0 gives the item a big promotion.
However, it does not necessarily mean that the boosted item will be the top
result at all times, nor that other items will be excluded. Results could
still be shown even when none of them matches the condition. And results that
are significantly more relevant to the search query can still trump your
heavily favored but irrelevant items. Setting to -1.0 gives the item a big
demotion. However, results that are deeply relevant might still be shown. The
item will have an upstream battle to get a fairly high ranking, but it is not
blocked out completely. Setting to 0.0 means no boost applied. The boosting
condition is ignored.
Corresponds to the JSON property boost
7879 7880 7881 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7879 def boost @boost end |
#condition ⇒ String
An expression which specifies a boost condition. The syntax and supported
fields are the same as a filter expression. See SearchRequest.filter for
detail syntax and limitations. Examples: * To boost products with product ID "
product_1" or "product_2", and color "Red" or "Blue": * (id: ANY("product_1", "
product_2")) AND (colorFamilies: ANY("Red","Blue"))
Corresponds to the JSON property condition
7888 7889 7890 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7888 def condition @condition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7895 7896 7897 7898 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7895 def update!(**args) @boost = args[:boost] if args.key?(:boost) @condition = args[:condition] if args.key?(:condition) end |