Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
This field specifies all conversational related parameters addition to traditional retail search.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
This field specifies the conversation id, which maintains the state of the conversation between client side and server side.
-
#followup_conversation_requested ⇒ Boolean
(also: #followup_conversation_requested?)
This field specifies whether the customer would like to do conversational search.
-
#user_answer ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpecUserAnswer
This field specifies the current user answer during the conversational search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpec
constructor
A new instance of GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpec
Returns a new instance of GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpec.
7928 7929 7930 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
This field specifies the conversation id, which maintains the state of the
conversation between client side and server side. Use the value from the
previous SearchResponse.ConversationalSearchResult.conversation_id. For the
initial request, this should be empty.
Corresponds to the JSON property conversationId
7910 7911 7912 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7910 def conversation_id @conversation_id end |
#followup_conversation_requested ⇒ Boolean Also known as: followup_conversation_requested?
This field specifies whether the customer would like to do conversational
search. If this field is set to true, conversational related extra information
will be returned from server side, including follow-up question, answer
options, etc.
Corresponds to the JSON property followupConversationRequested
7918 7919 7920 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7918 def followup_conversation_requested @followup_conversation_requested end |
#user_answer ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestConversationalSearchSpecUserAnswer
This field specifies the current user answer during the conversational search.
This can be either user selected from suggested answers or user input plain
text.
Corresponds to the JSON property userAnswer
7926 7927 7928 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7926 def user_answer @user_answer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7933 7934 7935 7936 7937 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 7933 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @followup_conversation_requested = args[:followup_conversation_requested] if args.key?(:followup_conversation_requested) @user_answer = args[:user_answer] if args.key?(:user_answer) end |