Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Specification to determine under which conditions query expansion should occur.
Instance Attribute Summary collapse
-
#condition ⇒ String
The condition under which query expansion should occur.
-
#pin_unexpanded_results ⇒ Boolean
(also: #pin_unexpanded_results?)
Whether to pin unexpanded results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
constructor
A new instance of GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
Returns a new instance of GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec.
8291 8292 8293 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
The condition under which query expansion should occur. Default to Condition.
DISABLED.
Corresponds to the JSON property condition
8281 8282 8283 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8281 def condition @condition end |
#pin_unexpanded_results ⇒ Boolean Also known as: pin_unexpanded_results?
Whether to pin unexpanded results. The default value is false. If this field
is set to true, unexpanded products are always at the top of the search
results, followed by the expanded results.
Corresponds to the JSON property pinUnexpandedResults
8288 8289 8290 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8288 def @pin_unexpanded_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8296 8297 8298 8299 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8296 def update!(**args) @condition = args[:condition] if args.key?(:condition) @pin_unexpanded_results = args[:pin_unexpanded_results] if args.key?(:pin_unexpanded_results) end |