Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Specification to determine under which conditions query expansion should occur.
Instance Attribute Summary collapse
-
#condition ⇒ String
The condition under which query expansion should occur.
-
#pin_unexpanded_results ⇒ Boolean
(also: #pin_unexpanded_results?)
Whether to pin unexpanded results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
constructor
A new instance of GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec
Returns a new instance of GoogleCloudRetailV2alphaSearchRequestQueryExpansionSpec.
8242 8243 8244 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
The condition under which query expansion should occur. Default to Condition.
DISABLED.
Corresponds to the JSON property condition
8232 8233 8234 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8232 def condition @condition end |
#pin_unexpanded_results ⇒ Boolean Also known as: pin_unexpanded_results?
Whether to pin unexpanded results. The default value is false. If this field
is set to true, unexpanded products are always at the top of the search
results, followed by the expanded results.
Corresponds to the JSON property pinUnexpandedResults
8239 8240 8241 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8239 def @pin_unexpanded_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8247 8248 8249 8250 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8247 def update!(**args) @condition = args[:condition] if args.key?(:condition) @pin_unexpanded_results = args[:pin_unexpanded_results] if args.key?(:pin_unexpanded_results) end |