Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

This field specifies tile navigation related parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec

Returns a new instance of GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec.



8296
8297
8298
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_tilesArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaTile>

This optional field specifies the tiles which are already clicked in client side. While the feature works without this field set, particularly for an initial query, it is highly recommended to set this field because it can improve the quality of the search response and removes possible duplicate tiles. NOTE: This field is not being used for filtering search products. Client side should also put all the applied tiles in SearchRequest.filter. Corresponds to the JSON property appliedTiles



8287
8288
8289
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8287

def applied_tiles
  @applied_tiles
end

#tile_navigation_requestedBoolean Also known as: tile_navigation_requested?

This field specifies whether the customer would like to request tile navigation. Corresponds to the JSON property tileNavigationRequested

Returns:

  • (Boolean)


8293
8294
8295
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8293

def tile_navigation_requested
  @tile_navigation_requested
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8301
8302
8303
8304
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8301

def update!(**args)
  @applied_tiles = args[:applied_tiles] if args.key?(:applied_tiles)
  @tile_navigation_requested = args[:tile_navigation_requested] if args.key?(:tile_navigation_requested)
end