Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
This field specifies tile navigation related parameters.
Instance Attribute Summary collapse
-
#applied_tiles ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaTile>
This optional field specifies the tiles which are already clicked in client side.
-
#tile_navigation_requested ⇒ Boolean
(also: #tile_navigation_requested?)
This field specifies whether the customer would like to request tile navigation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec
constructor
A new instance of GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec
Returns a new instance of GoogleCloudRetailV2alphaSearchRequestTileNavigationSpec.
8294 8295 8296 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8294 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_tiles ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaTile>
This optional field specifies the tiles which are already clicked in client
side. While the feature works without this field set, particularly for an
initial query, it is highly recommended to set this field because it can
improve the quality of the search response and removes possible duplicate
tiles. NOTE: This field is not being used for filtering search products.
Client side should also put all the applied tiles in SearchRequest.filter.
Corresponds to the JSON property appliedTiles
8285 8286 8287 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8285 def applied_tiles @applied_tiles end |
#tile_navigation_requested ⇒ Boolean Also known as:
This field specifies whether the customer would like to request tile
navigation.
Corresponds to the JSON property tileNavigationRequested
8291 8292 8293 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8291 def @tile_navigation_requested end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8299 8300 8301 8302 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8299 def update!(**args) @applied_tiles = args[:applied_tiles] if args.key?(:applied_tiles) @tile_navigation_requested = args[:tile_navigation_requested] if args.key?(:tile_navigation_requested) end |