Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

Response message for SearchService.Search method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchResponse

Returns a new instance of GoogleCloudRetailV2alphaSearchResponse.



8399
8400
8401
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_controlsArray<String>

The fully qualified resource name of applied controls. Corresponds to the JSON property appliedControls

Returns:

  • (Array<String>)


8316
8317
8318
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8316

def applied_controls
  @applied_controls
end

#attribution_tokenString

A unique search token. This should be included in the UserEvent logs resulting from this search, which enables accurate attribution of search model performance. Corresponds to the JSON property attributionToken

Returns:

  • (String)


8323
8324
8325
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8323

def attribution_token
  @attribution_token
end

#conversational_search_resultGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResult

This field specifies all related information that is needed on client side for UI rendering of conversational retail search. Corresponds to the JSON property conversationalSearchResult



8329
8330
8331
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8329

def conversational_search_result
  @conversational_search_result
end

#corrected_queryString

Contains the spell corrected query, if found. The search results are based on corrected_query by default. However, if SearchRequest.SpellCorrectionSpec.mode is set to SearchRequest.SpellCorrectionSpec.Mode.SUGGESTION_ONLY, the original query is used for search. Corresponds to the JSON property correctedQuery

Returns:

  • (String)


8337
8338
8339
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8337

def corrected_query
  @corrected_query
end

#experiment_infoArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExperimentInfo>

Metadata related to A/B testing experiment associated with this response. Only exists when an experiment is triggered. Corresponds to the JSON property experimentInfo



8343
8344
8345
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8343

def experiment_info
  @experiment_info
end

#facetsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseFacet>

Results of facets requested by user. Corresponds to the JSON property facets



8348
8349
8350
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8348

def facets
  @facets
end

#invalid_condition_boost_specsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec>

The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied during serving. Corresponds to the JSON property invalidConditionBoostSpecs



8354
8355
8356
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8354

def invalid_condition_boost_specs
  @invalid_condition_boost_specs
end

#next_page_tokenString

A token that can be sent as SearchRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8360
8361
8362
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8360

def next_page_token
  @next_page_token
end

#pin_control_metadataGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPinControlMetadata

Metadata for pinning to be returned in the response. This is used for distinguishing between applied vs dropped pins. Corresponds to the JSON property pinControlMetadata



8366
8367
8368
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8366

def 
  @pin_control_metadata
end

#query_expansion_infoGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseQueryExpansionInfo

Information describing query expansion including whether expansion has occurred. Corresponds to the JSON property queryExpansionInfo



8372
8373
8374
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8372

def query_expansion_info
  @query_expansion_info
end

#redirect_uriString

The URI of a customer-defined redirect page. If redirect action is triggered, no search is performed, and only redirect_uri and attribution_token are set in the response. Corresponds to the JSON property redirectUri

Returns:

  • (String)


8379
8380
8381
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8379

def redirect_uri
  @redirect_uri
end

#resultsArray<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseSearchResult>

A list of matched items. The order represents the ranking. Corresponds to the JSON property results



8384
8385
8386
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8384

def results
  @results
end

#tile_navigation_resultGoogle::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseTileNavigationResult

This field specifies all related information for tile navigation that will be used in client side. Corresponds to the JSON property tileNavigationResult



8390
8391
8392
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8390

def tile_navigation_result
  @tile_navigation_result
end

#total_sizeFixnum

The estimated total count of matched items irrespective of pagination. The count of results returned by pagination may be less than the total_size that matches. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


8397
8398
8399
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8397

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8404
8405
8406
8407
8408
8409
8410
8411
8412
8413
8414
8415
8416
8417
8418
8419
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8404

def update!(**args)
  @applied_controls = args[:applied_controls] if args.key?(:applied_controls)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @conversational_search_result = args[:conversational_search_result] if args.key?(:conversational_search_result)
  @corrected_query = args[:corrected_query] if args.key?(:corrected_query)
  @experiment_info = args[:experiment_info] if args.key?(:experiment_info)
  @facets = args[:facets] if args.key?(:facets)
  @invalid_condition_boost_specs = args[:invalid_condition_boost_specs] if args.key?(:invalid_condition_boost_specs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @pin_control_metadata = args[:pin_control_metadata] if args.key?(:pin_control_metadata)
  @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @results = args[:results] if args.key?(:results)
  @tile_navigation_result = args[:tile_navigation_result] if args.key?(:tile_navigation_result)
  @total_size = args[:total_size] if args.key?(:total_size)
end