Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response message for SearchService.Search method.
Instance Attribute Summary collapse
-
#applied_controls ⇒ Array<String>
The fully qualified resource name of applied controls.
-
#attribution_token ⇒ String
A unique search token.
-
#conversational_search_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResult
This field specifies all related information that is needed on client side for UI rendering of conversational retail search.
-
#corrected_query ⇒ String
Contains the spell corrected query, if found.
-
#experiment_info ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExperimentInfo>
Metadata related to A/B testing experiment associated with this response.
-
#facets ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseFacet>
Results of facets requested by user.
-
#invalid_condition_boost_specs ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec>
The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied during serving.
-
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
-
#pin_control_metadata ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPinControlMetadata
Metadata for pinning to be returned in the response.
-
#query_expansion_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has occurred.
-
#redirect_uri ⇒ String
The URI of a customer-defined redirect page.
-
#results ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseSearchResult>
A list of matched items.
-
#tile_navigation_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseTileNavigationResult
This field specifies all related information for tile navigation that will be used in client side.
-
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchResponse
constructor
A new instance of GoogleCloudRetailV2alphaSearchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaSearchResponse
Returns a new instance of GoogleCloudRetailV2alphaSearchResponse.
8395 8396 8397 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_controls ⇒ Array<String>
The fully qualified resource name of applied controls.
Corresponds to the JSON property appliedControls
8313 8314 8315 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8313 def applied_controls @applied_controls end |
#attribution_token ⇒ String
A unique search token. This should be included in the UserEvent logs resulting
from this search, which enables accurate attribution of search model
performance.
Corresponds to the JSON property attributionToken
8320 8321 8322 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8320 def attribution_token @attribution_token end |
#conversational_search_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseConversationalSearchResult
This field specifies all related information that is needed on client side for
UI rendering of conversational retail search.
Corresponds to the JSON property conversationalSearchResult
8326 8327 8328 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8326 def conversational_search_result @conversational_search_result end |
#corrected_query ⇒ String
Contains the spell corrected query, if found. If the spell correction type is
AUTOMATIC, then the search results are based on corrected_query. Otherwise the
original query is used for search.
Corresponds to the JSON property correctedQuery
8333 8334 8335 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8333 def corrected_query @corrected_query end |
#experiment_info ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaExperimentInfo>
Metadata related to A/B testing experiment associated with this response. Only
exists when an experiment is triggered.
Corresponds to the JSON property experimentInfo
8339 8340 8341 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8339 def experiment_info @experiment_info end |
#facets ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseFacet>
Results of facets requested by user.
Corresponds to the JSON property facets
8344 8345 8346 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8344 def facets @facets end |
#invalid_condition_boost_specs ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchRequestBoostSpecConditionBoostSpec>
The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied
during serving.
Corresponds to the JSON property invalidConditionBoostSpecs
8350 8351 8352 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8350 def invalid_condition_boost_specs @invalid_condition_boost_specs end |
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
8356 8357 8358 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8356 def next_page_token @next_page_token end |
#pin_control_metadata ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaPinControlMetadata
Metadata for pinning to be returned in the response. This is used for
distinguishing between applied vs dropped pins.
Corresponds to the JSON property pinControlMetadata
8362 8363 8364 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8362 def @pin_control_metadata end |
#query_expansion_info ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has
occurred.
Corresponds to the JSON property queryExpansionInfo
8368 8369 8370 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8368 def query_expansion_info @query_expansion_info end |
#redirect_uri ⇒ String
The URI of a customer-defined redirect page. If redirect action is triggered,
no search is performed, and only redirect_uri and attribution_token are set in
the response.
Corresponds to the JSON property redirectUri
8375 8376 8377 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8375 def redirect_uri @redirect_uri end |
#results ⇒ Array<Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseSearchResult>
A list of matched items. The order represents the ranking.
Corresponds to the JSON property results
8380 8381 8382 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8380 def results @results end |
#tile_navigation_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaSearchResponseTileNavigationResult
This field specifies all related information for tile navigation that will be
used in client side.
Corresponds to the JSON property tileNavigationResult
8386 8387 8388 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8386 def @tile_navigation_result end |
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination. The
count of results returned by pagination may be less than the total_size that
matches.
Corresponds to the JSON property totalSize
8393 8394 8395 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8393 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8400 8401 8402 8403 8404 8405 8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 8400 def update!(**args) @applied_controls = args[:applied_controls] if args.key?(:applied_controls) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @conversational_search_result = args[:conversational_search_result] if args.key?(:conversational_search_result) @corrected_query = args[:corrected_query] if args.key?(:corrected_query) @experiment_info = args[:experiment_info] if args.key?(:experiment_info) @facets = args[:facets] if args.key?(:facets) @invalid_condition_boost_specs = args[:invalid_condition_boost_specs] if args.key?(:invalid_condition_boost_specs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @pin_control_metadata = args[:pin_control_metadata] if args.key?(:pin_control_metadata) @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @results = args[:results] if args.key?(:results) @tile_navigation_result = args[:tile_navigation_result] if args.key?(:tile_navigation_result) @total_size = args[:total_size] if args.key?(:total_size) end |