Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaTransformedUserEventsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2alphaTransformedUserEventsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Metadata related to transform user events operation.
Instance Attribute Summary collapse
-
#source_events_count ⇒ Fixnum
Count of entries in the source user events BigQuery table.
-
#transformed_events_count ⇒ Fixnum
Count of entries in the transformed user events BigQuery table, which could be different from the actually imported number of user events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaTransformedUserEventsMetadata
constructor
A new instance of GoogleCloudRetailV2alphaTransformedUserEventsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaTransformedUserEventsMetadata
Returns a new instance of GoogleCloudRetailV2alphaTransformedUserEventsMetadata.
9103 9104 9105 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_events_count ⇒ Fixnum
Count of entries in the source user events BigQuery table.
Corresponds to the JSON property sourceEventsCount
9095 9096 9097 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9095 def source_events_count @source_events_count end |
#transformed_events_count ⇒ Fixnum
Count of entries in the transformed user events BigQuery table, which could be
different from the actually imported number of user events.
Corresponds to the JSON property transformedEventsCount
9101 9102 9103 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9101 def transformed_events_count @transformed_events_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9108 9109 9110 9111 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9108 def update!(**args) @source_events_count = args[:source_events_count] if args.key?(:source_events_count) @transformed_events_count = args[:transformed_events_count] if args.key?(:transformed_events_count) end |