Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaExportUserEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaExportUserEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response of the ExportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaExportErrorsConfig
Configuration of destination for Export related errors.
-
#output_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaOutputResult
Output result that stores the information about where the exported data is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaExportUserEventsResponse
constructor
A new instance of GoogleCloudRetailV2betaExportUserEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaExportUserEventsResponse
Returns a new instance of GoogleCloudRetailV2betaExportUserEventsResponse.
9809 9810 9811 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9809 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
9796 9797 9798 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9796 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaExportErrorsConfig
Configuration of destination for Export related errors.
Corresponds to the JSON property errorsConfig
9801 9802 9803 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9801 def errors_config @errors_config end |
#output_result ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaOutputResult
Output result that stores the information about where the exported data is
stored.
Corresponds to the JSON property outputResult
9807 9808 9809 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9807 def output_result @output_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9814 9815 9816 9817 9818 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9814 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @output_result = args[:output_result] if args.key?(:output_result) end |