Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportUserEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportUserEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportErrorsConfig
Configuration of destination for Import related errors.
-
#import_summary ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaUserEventImportSummary
A summary of import result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaImportUserEventsResponse
constructor
A new instance of GoogleCloudRetailV2betaImportUserEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaImportUserEventsResponse
Returns a new instance of GoogleCloudRetailV2betaImportUserEventsResponse.
9986 9987 9988 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
9973 9974 9975 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9973 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportErrorsConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorsConfig
9978 9979 9980 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9978 def errors_config @errors_config end |
#import_summary ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaUserEventImportSummary
A summary of import result. The UserEventImportSummary summarizes the import
status for user events.
Corresponds to the JSON property importSummary
9984 9985 9986 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9984 def import_summary @import_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9991 9992 9993 9994 9995 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9991 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @import_summary = args[:import_summary] if args.key?(:import_summary) end |