Class: Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportUserEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportUserEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb
Overview
Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportErrorsConfig
Configuration of destination for Import related errors.
-
#import_summary ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaUserEventImportSummary
A summary of import result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaImportUserEventsResponse
constructor
A new instance of GoogleCloudRetailV2betaImportUserEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaImportUserEventsResponse
Returns a new instance of GoogleCloudRetailV2betaImportUserEventsResponse.
9985 9986 9987 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2alpha::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
9972 9973 9974 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9972 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaImportErrorsConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorsConfig
9977 9978 9979 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9977 def errors_config @errors_config end |
#import_summary ⇒ Google::Apis::RetailV2alpha::GoogleCloudRetailV2betaUserEventImportSummary
A summary of import result. The UserEventImportSummary summarizes the import
status for user events.
Corresponds to the JSON property importSummary
9983 9984 9985 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9983 def import_summary @import_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9990 9991 9992 9993 9994 |
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 9990 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @import_summary = args[:import_summary] if args.key?(:import_summary) end |