Class: Google::Apis::RetailV2alpha::GoogleLongrunningOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2alpha/classes.rb,
lib/google/apis/retail_v2alpha/representations.rb,
lib/google/apis/retail_v2alpha/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningOperation

Returns a new instance of GoogleLongrunningOperation.



10597
10598
10599
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true , the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


10558
10559
10560
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10558

def done
  @done
end

#errorGoogle::Apis::RetailV2alpha::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



10569
10570
10571
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10569

def error
  @error
end

#metadataHash<String,Object>

Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


10577
10578
10579
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10577

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/unique_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


10584
10585
10586
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10584

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


10595
10596
10597
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10595

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10602
10603
10604
10605
10606
10607
10608
# File 'lib/google/apis/retail_v2alpha/classes.rb', line 10602

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end